# coding=utf8

# Copyright 2018 JDCLOUD.COM
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# NOTE: This class is auto generated by the jdcloud code generator program.

from argparse import RawTextHelpFormatter
from jdcloud_cli.cement.ext.ext_argparse import expose
from jdcloud_cli.controllers.base_controller import BaseController
from jdcloud_cli.client_factory import ClientFactory
from jdcloud_cli.parameter_builder import collect_user_args, collect_user_headers
from jdcloud_cli.printer import Printer
from jdcloud_cli.skeleton import Skeleton


class EliteController(BaseController):
    class Meta:
        label = 'elite'
        help = 'elite相关API'
        description = '''
        elite cli 子命令，elite相关API。
        OpenAPI文档地址为：https://docs.jdcloud.com/cn/jd-cloud-elite/api/overview
        '''
        stacked_on = 'base'
        stacked_type = 'nested'

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--order-number'], dict(help="""(string) 订单号 """, dest='orderNumber',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 查询交付信息接口 ''',
        description='''
            查询交付信息接口。

            示例: jdc elite jdx-query-delivery-info  --order-number xxx
        ''',
    )
    def jdx_query_delivery_info(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.JdxQueryDeliveryInfoRequest import JdxQueryDeliveryInfoRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = JdxQueryDeliveryInfoRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--buyer-pin'], dict(help="""(string) 购买用户pin """, dest='buyerPin',  required=True)),
            (['--business-data'], dict(help="""(string) 业务数据，与下单时的业务数据一致 """, dest='businessData',  required=True)),
            (['--query-all'], dict(help="""(bool) 是否查询全部，如果传入false，则只查询当前时间有效的，否则查询所有的 """, dest='queryAll', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 获取云存服务信息 ''',
        description='''
            获取云存服务信息。

            示例: jdc elite get-store-service  --buyer-pin xxx --business-data xxx
        ''',
    )
    def get_store_service(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.GetStoreServiceRequest import GetStoreServiceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = GetStoreServiceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--page-no'], dict(help="""(int) 页码（最小1） """, dest='pageNo', type=int, required=True)),
            (['--page-size'], dict(help="""(int) 每页记录数（最小10，最大100） """, dest='pageSize', type=int, required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 输出商品接口 ''',
        description='''
            输出商品接口。

            示例: jdc elite jdx-query-product  --page-no 5 --page-size 5
        ''',
    )
    def jdx_query_product(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.JdxQueryProductRequest import JdxQueryProductRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = JdxQueryProductRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--page-no'], dict(help="""(int) 页码（最小1） """, dest='pageNo', type=int, required=True)),
            (['--page-size'], dict(help="""(int) 每页记录数（最小10，最大100） """, dest='pageSize', type=int, required=True)),
            (['--deliver-number'], dict(help="""(string) 交付单号 """, dest='deliverNumber',  required=False)),
            (['--deliver-status'], dict(help="""(int) 交付状态 """, dest='deliverStatus', type=int, required=False)),
            (['--create-dt-start'], dict(help="""(string) 交付单创建起始时间，格式：yyyy-MM-dd HH:mm:ss """, dest='createDtStart',  required=False)),
            (['--create-dt-end'], dict(help="""(string) 交付单创建结束时间，格式：yyyy-MM-dd HH:mm:ss """, dest='createDtEnd',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 分页查询交付单信息 ''',
        description='''
            分页查询交付单信息。

            示例: jdc elite list-sale-service  --page-no 5 --page-size 5
        ''',
    )
    def list_sale_service(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.ListSaleServiceRequest import ListSaleServiceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ListSaleServiceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--deliver-number'], dict(help="""(string) 交付单号 """, dest='deliverNumber',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 根据交付单号查询交付单信息 ''',
        description='''
            根据交付单号查询交付单信息。

            示例: jdc elite get-sale-service-by-deliver-number  --deliver-number xxx
        ''',
    )
    def get_sale_service_by_deliver_number(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.GetSaleServiceByDeliverNumberRequest import GetSaleServiceByDeliverNumberRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = GetSaleServiceByDeliverNumberRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--confirm-delivery-info'], dict(help="""(confirmDeliveryInfo) 交付信息 """, dest='confirmDeliveryInfo',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 确认交付 ''',
        description='''
            确认交付。

            示例: jdc elite confirm-sale-service-delivery  --confirm-delivery-info '{"":""}'
        ''',
    )
    def confirm_sale_service_delivery(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.ConfirmSaleServiceDeliveryRequest import ConfirmSaleServiceDeliveryRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ConfirmSaleServiceDeliveryRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--report-order-info'], dict(help="""(reportOrderInfo) 上报订单信息 """, dest='reportOrderInfo',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 上报订单 ''',
        description='''
            上报订单。

            示例: jdc elite jdx-report-order  --report-order-info '{"":""}'
        ''',
    )
    def jdx_report_order(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.JdxReportOrderRequest import JdxReportOrderRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = JdxReportOrderRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--create-order-info'], dict(help="""(createOrderInfo) 下单信息 """, dest='createOrderInfo',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 下单接口 ''',
        description='''
            下单接口。

            示例: jdc elite jdx-create-order  --create-order-info '{"":""}'
        ''',
    )
    def jdx_create_order(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.JdxCreateOrderRequest import JdxCreateOrderRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = JdxCreateOrderRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID """, dest='regionId',  required=False)),
            (['--query-price-param'], dict(help="""(queryPriceParam) 查询价格参数 """, dest='queryPriceParam',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 查询价格 ''',
        description='''
            查询价格。

            示例: jdc elite jdx-query-price  --query-price-param '{"":""}'
        ''',
    )
    def jdx_query_price(self):
        client_factory = ClientFactory('elite')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.elite.apis.JdxQueryPriceRequest import JdxQueryPriceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = JdxQueryPriceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--api'], dict(help="""(string) api name """, choices=['jdx-query-delivery-info','get-store-service','jdx-query-product','list-sale-service','get-sale-service-by-deliver-number','confirm-sale-service-delivery','jdx-report-order','jdx-create-order','jdx-query-price',], required=True)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 生成单个API接口的json骨架空字符串 ''',
        description='''
            生成单个API接口的json骨架空字符串。

            示例: jdc nc generate-skeleton --api describeContainer ''',
    )
    def generate_skeleton(self):
        skeleton = Skeleton('elite', self.app.pargs.api)
        skeleton.show()
