# coding=utf8

# Copyright 2018 JDCLOUD.COM
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# NOTE: This class is auto generated by the jdcloud code generator program.

from argparse import RawTextHelpFormatter
from jdcloud_cli.cement.ext.ext_argparse import expose
from jdcloud_cli.controllers.base_controller import BaseController
from jdcloud_cli.client_factory import ClientFactory
from jdcloud_cli.parameter_builder import collect_user_args, collect_user_headers
from jdcloud_cli.printer import Printer
from jdcloud_cli.skeleton import Skeleton


class VmController(BaseController):
    class Meta:
        label = 'vm'
        help = '云主机'
        description = '''
        vm cli 子命令，云主机实例、镜像、实例规格、实例模板、配额相关的接口。
        OpenAPI文档地址为：https://docs.jdcloud.com/cn/virtual-machines/api/overview
        '''
        stacked_on = 'base'
        stacked_type = 'nested'

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `name`: 实例模板名称，模糊匹配，支持多个; `instanceTemplateId`: 实例模板ID，精确匹配，支持多个;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询实例模板列表。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条实例模板数据。;  ''',
        description='''
            ; 查询实例模板列表。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条实例模板数据。; 。

            示例: jdc vm describe-instance-templates 
        ''',
    )
    def describe_instance_templates(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceTemplatesRequest import DescribeInstanceTemplatesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceTemplatesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-template-data'], dict(help="""(instanceTemplateSpec) 实例模板配置信息。 """, dest='instanceTemplateData',  required=True)),
            (['--name'], dict(help="""(string) 实例模板的名称，参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='name',  required=True)),
            (['--description'], dict(help="""(string) 实例模板的描述，参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='description',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 创建实例模板。; ; 实例模板是创建云主机实例的配置信息模板，包括镜像、实例规格、系统盘及数据盘类型和容量、私有网络及子网配置、安全组及登录信息等。实例模板可用于创建实例及用于配置高可用组（创建高可用组时必须指定实例模板）。使用实例模板创建实例时，无需重新指定实例模板已包括的参数，缩短您的部署时间。; ; 请注意：实例模板一经创建后其属性将不能编辑，如需调整参数请重新创建实例模板替换使用。; ; 详细操作说明请参考帮助文档：[创建实例模板](https://docs.jdcloud.com/cn/virtual-machines/create-instance-template); ; ## 接口说明; - 创建实例模板的限制基本与创建云主机一致，可参考 [创建云主机](https://docs.jdcloud.com/cn/virtual-machines/create-instance)。; - 实例模板中包含创建云主机的大部分配置参数，可以避免每次创建云主机时的重复性配置参数的工作。; - 使用实例模板创建云主机时，如果再次指定了某些参数，并且与实例模板中的参数相冲突，那么新指定的参数会替换模板中的参数，以新指定的参数为准。; - 使用实例模板创建云主机时，如果再次指定了镜像ID，并且与模板中的镜像ID不一致，那么模板中的 `systemDisk` 和 `dataDisks` 配置会失效，以新指定的镜像为准。; - 如果使用高可用组(Ag)创建云主机，那么Ag所关联的模板中的参数都不可以被调整，只能以模板为准。;  ''',
        description='''
            ; 创建实例模板。; ; 实例模板是创建云主机实例的配置信息模板，包括镜像、实例规格、系统盘及数据盘类型和容量、私有网络及子网配置、安全组及登录信息等。实例模板可用于创建实例及用于配置高可用组（创建高可用组时必须指定实例模板）。使用实例模板创建实例时，无需重新指定实例模板已包括的参数，缩短您的部署时间。; ; 请注意：实例模板一经创建后其属性将不能编辑，如需调整参数请重新创建实例模板替换使用。; ; 详细操作说明请参考帮助文档：[创建实例模板](https://docs.jdcloud.com/cn/virtual-machines/create-instance-template); ; ## 接口说明; - 创建实例模板的限制基本与创建云主机一致，可参考 [创建云主机](https://docs.jdcloud.com/cn/virtual-machines/create-instance)。; - 实例模板中包含创建云主机的大部分配置参数，可以避免每次创建云主机时的重复性配置参数的工作。; - 使用实例模板创建云主机时，如果再次指定了某些参数，并且与实例模板中的参数相冲突，那么新指定的参数会替换模板中的参数，以新指定的参数为准。; - 使用实例模板创建云主机时，如果再次指定了镜像ID，并且与模板中的镜像ID不一致，那么模板中的 `systemDisk` 和 `dataDisks` 配置会失效，以新指定的镜像为准。; - 如果使用高可用组(Ag)创建云主机，那么Ag所关联的模板中的参数都不可以被调整，只能以模板为准。; 。

            示例: jdc vm create-instance-template  --instance-template-data '{"":""}' --name xxx
        ''',
    )
    def create_instance_template(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.CreateInstanceTemplateRequest import CreateInstanceTemplateRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = CreateInstanceTemplateRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-template-id'], dict(help="""(string) 实例模板ID。 """, dest='instanceTemplateId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询实例模板详情。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 该接口与查询实例模板列表返回的信息一致。; - 只需要查询单个实例模板详细信息的时候可以调用该接口。;  ''',
        description='''
            ; 查询实例模板详情。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 该接口与查询实例模板列表返回的信息一致。; - 只需要查询单个实例模板详细信息的时候可以调用该接口。; 。

            示例: jdc vm describe-instance-template  --instance-template-id xxx
        ''',
    )
    def describe_instance_template(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceTemplateRequest import DescribeInstanceTemplateRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceTemplateRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-template-id'], dict(help="""(string) 实例模板ID。 """, dest='instanceTemplateId',  required=True)),
            (['--name'], dict(help="""(string) 实例模板的名称，参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='name',  required=False)),
            (['--description'], dict(help="""(string) 实例模板的描述，参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='description',  required=False)),
            (['--instance-template-data'], dict(help="""(updateInstanceTemplateSpec) 实例模板配置信息。 """, dest='instanceTemplateData',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改实例模板属性。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 名称、描述、实例模板配置信息至少要传一项。; - 参数时，对应的参数不做更改。;  ''',
        description='''
            ; 修改实例模板属性。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 名称、描述、实例模板配置信息至少要传一项。; - 参数时，对应的参数不做更改。; 。

            示例: jdc vm update-instance-template  --instance-template-id xxx
        ''',
    )
    def update_instance_template(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.UpdateInstanceTemplateRequest import UpdateInstanceTemplateRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = UpdateInstanceTemplateRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-template-id'], dict(help="""(string) 实例模板ID。 """, dest='instanceTemplateId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 删除单个实例模板。; ; 详细操作说明请参考帮助文档：[删除实例模板](https://docs.jdcloud.com/cn/virtual-machines/delete-instance-template); ; ## 接口说明; - 关联了高可用组的实例模板不可以删除。;  ''',
        description='''
            ; 删除单个实例模板。; ; 详细操作说明请参考帮助文档：[删除实例模板](https://docs.jdcloud.com/cn/virtual-machines/delete-instance-template); ; ## 接口说明; - 关联了高可用组的实例模板不可以删除。; 。

            示例: jdc vm delete-instance-template  --instance-template-id xxx
        ''',
    )
    def delete_instance_template(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DeleteInstanceTemplateRequest import DeleteInstanceTemplateRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DeleteInstanceTemplateRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-template-id'], dict(help="""(string) 实例模板ID。 """, dest='instanceTemplateId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 校验实例模板的有效性。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 调用该接口可以校验实例模板是否有效，例如某些关联资源可能已经被删除了，此刻实例模板可能已经失效了。;  ''',
        description='''
            ; 校验实例模板的有效性。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 调用该接口可以校验实例模板是否有效，例如某些关联资源可能已经被删除了，此刻实例模板可能已经失效了。; 。

            示例: jdc vm verify-instance-template  --instance-template-id xxx
        ''',
    )
    def verify_instance_template(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.VerifyInstanceTemplateRequest import VerifyInstanceTemplateRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = VerifyInstanceTemplateRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceTemplateId`: 实例模板ID，精确匹配，最多支持10个;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询实例模板上的自定义元数据。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 一般情况下由于自定义元数据比较大，所以限制每次最多查询10个实例模板。;  ''',
        description='''
            ; 查询实例模板上的自定义元数据。; ; 详细操作说明请参考帮助文档：[实例模板](https://docs.jdcloud.com/cn/virtual-machines/instance-template-overview); ; ## 接口说明; - 一般情况下由于自定义元数据比较大，所以限制每次最多查询10个实例模板。; 。

            示例: jdc vm describe-instance-templates-customdata 
        ''',
    )
    def describe_instance_templates_customdata(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceTemplatesCustomdataRequest import DescribeInstanceTemplatesCustomdataRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceTemplatesCustomdataRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `keyNames`: 密钥对名称，精确匹配，支持多个;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 批量查询密钥对。; ; 详细操作说明请参考帮助文档：[密钥概述](https://docs.jdcloud.com/cn/virtual-machines/keypair-overview); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条密钥数据。;  ''',
        description='''
            ; 批量查询密钥对。; ; 详细操作说明请参考帮助文档：[密钥概述](https://docs.jdcloud.com/cn/virtual-machines/keypair-overview); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条密钥数据。; 。

            示例: jdc vm describe-keypairs 
        ''',
    )
    def describe_keypairs(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeKeypairsRequest import DescribeKeypairsRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeKeypairsRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--key-name'], dict(help="""(string) 密钥对名称，需要全局唯一。; 只允许数字、大小写字母、下划线“_”及中划线“-”，不超过32个字符。;  """, dest='keyName',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 创建密钥。; ; 公钥和私钥都由京东云生成，公钥保存在京东云，私钥返回给用户，由用户保存。; ; 详细操作说明请参考帮助文档：[创建密钥](https://docs.jdcloud.com/cn/virtual-machines/create-keypair); ; ## 接口说明; - 调用该接口创建密钥后，公钥部分存储在京东云，并返回未加密的 `PEM` 编码的 `PKCS#8` 格式私钥，您只有一次机会保存您的私钥。请妥善保管。;  ''',
        description='''
            ; 创建密钥。; ; 公钥和私钥都由京东云生成，公钥保存在京东云，私钥返回给用户，由用户保存。; ; 详细操作说明请参考帮助文档：[创建密钥](https://docs.jdcloud.com/cn/virtual-machines/create-keypair); ; ## 接口说明; - 调用该接口创建密钥后，公钥部分存储在京东云，并返回未加密的 `PEM` 编码的 `PKCS#8` 格式私钥，您只有一次机会保存您的私钥。请妥善保管。; 。

            示例: jdc vm create-keypair  --key-name xxx
        ''',
    )
    def create_keypair(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.CreateKeypairRequest import CreateKeypairRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = CreateKeypairRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--key-name'], dict(help="""(string) 密钥对名称，需要全局唯一。; 只允许数字、大小写字母、下划线“_”及中划线“-”，不超过32个字符。;  """, dest='keyName',  required=True)),
            (['--public-key'], dict(help="""(string) 密钥对的公钥部分。 """, dest='publicKey',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 导入密钥。; ; 与创建密钥不同的是，导入的密钥是由用户生成的。生成之后将公钥部分导入到京东云。; ; 详细操作说明请参考帮助文档：[创建密钥](https://docs.jdcloud.com/cn/virtual-machines/create-keypair); ; ## 接口说明; - 调用该接口导入由其他工具生成的密钥对的公钥部分。;  ''',
        description='''
            ; 导入密钥。; ; 与创建密钥不同的是，导入的密钥是由用户生成的。生成之后将公钥部分导入到京东云。; ; 详细操作说明请参考帮助文档：[创建密钥](https://docs.jdcloud.com/cn/virtual-machines/create-keypair); ; ## 接口说明; - 调用该接口导入由其他工具生成的密钥对的公钥部分。; 。

            示例: jdc vm import-keypair  --key-name xxx --public-key xxx
        ''',
    )
    def import_keypair(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ImportKeypairRequest import ImportKeypairRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ImportKeypairRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--key-name'], dict(help="""(string) 密钥名称。 """, dest='keyName',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 删除密钥。; ; 详细操作说明请参考帮助文档：[删除密钥](https://docs.jdcloud.com/cn/virtual-machines/delete-keypair); ; ## 接口说明; - 密钥删除后，使用该密钥的实例仍可正常使用与之匹配的本地私钥登录，且密钥仍会显示在实例详情中。; - 密钥删除后，与之关联的实例模板将变为不可用，并且与该实例模板关联的高可用组也会变为不可用。;  ''',
        description='''
            ; 删除密钥。; ; 详细操作说明请参考帮助文档：[删除密钥](https://docs.jdcloud.com/cn/virtual-machines/delete-keypair); ; ## 接口说明; - 密钥删除后，使用该密钥的实例仍可正常使用与之匹配的本地私钥登录，且密钥仍会显示在实例详情中。; - 密钥删除后，与之关联的实例模板将变为不可用，并且与该实例模板关联的高可用组也会变为不可用。; 。

            示例: jdc vm delete-keypair  --key-name xxx
        ''',
    )
    def delete_keypair(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DeleteKeypairRequest import DeleteKeypairRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DeleteKeypairRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--key-name'], dict(help="""(string) 密钥名称。 """, dest='keyName',  required=True)),
            (['--instance-ids'], dict(help="""(array: string) 要绑定的云主机Id列表。 """, dest='instanceIds',  required=False)),
            (['--pass-word-auth'], dict(help="""(string) 绑定密钥后，根据此参数决定是否允许使用密码登录。可选范围：; `yes`：允许SSH密码登录。; `no`：禁止SSH密码登录。;  """, dest='passWordAuth',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机实例绑定密钥。; ; 详细操作说明请参考帮助文档：[绑定密钥](https://docs.jdcloud.com/cn/virtual-machines/bind-keypair); ; ## 接口说明; - 只支持为 linux 云主机实例绑定密钥。; - 每台云主机实例只支持绑定一个密钥。如果云主机绑定的密钥被删除了，那么该云主机还可以再次绑定密钥。;  ''',
        description='''
            ; 为云主机实例绑定密钥。; ; 详细操作说明请参考帮助文档：[绑定密钥](https://docs.jdcloud.com/cn/virtual-machines/bind-keypair); ; ## 接口说明; - 只支持为 linux 云主机实例绑定密钥。; - 每台云主机实例只支持绑定一个密钥。如果云主机绑定的密钥被删除了，那么该云主机还可以再次绑定密钥。; 。

            示例: jdc vm attach-keypair  --key-name xxx --pass-word-auth xxx
        ''',
    )
    def attach_keypair(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.AttachKeypairRequest import AttachKeypairRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = AttachKeypairRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--key-name'], dict(help="""(string) 密钥名称。 """, dest='keyName',  required=True)),
            (['--instance-ids'], dict(help="""(array: string) 要解绑的云主机实例ID列表。 """, dest='instanceIds',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机实例解绑密钥。; ; 详细操作说明请参考帮助文档：[绑定密钥](https://docs.jdcloud.com/cn/virtual-machines/bind-keypair); ; ## 接口说明; - 调用该接口解绑云主机实例中的密钥。;  ''',
        description='''
            ; 为云主机实例解绑密钥。; ; 详细操作说明请参考帮助文档：[绑定密钥](https://docs.jdcloud.com/cn/virtual-machines/bind-keypair); ; ## 接口说明; - 调用该接口解绑云主机实例中的密钥。; 。

            示例: jdc vm detach-keypair  --key-name xxx
        ''',
    )
    def detach_keypair(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DetachKeypairRequest import DetachKeypairRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DetachKeypairRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询镜像详情。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 该接口与查询镜像信息列表返回的信息一致。; - 只需要查询单个镜像信息的时候可以调用该接口。;  ''',
        description='''
            ; 查询镜像详情。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 该接口与查询镜像信息列表返回的信息一致。; - 只需要查询单个镜像信息的时候可以调用该接口。; 。

            示例: jdc vm describe-image  --image-id xxx
        ''',
    )
    def describe_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeImageRequest import DescribeImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--delete-snapshot'], dict(help="""(bool) 删除镜像时是否删除关联的快照。默认为 `false`；如果指定为 `true`, 将会删除镜像关联的快照。;  """, dest='deleteSnapshot', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 删除一个私有镜像。; ; 详细操作说明请参考帮助文档：[删除私有镜像](https://docs.jdcloud.com/cn/virtual-machines/delete-private-image); ; ## 接口说明; - 已共享的私有镜像在取消共享关系前不可以删除，如私有镜像已共享给其他用户，请取消共享后再进行删除。; - 本地系统盘镜像在有基于其创建的云主机时，将无法删除。; - 只能操作私有镜像。; - 私有镜像没有正在处理中的任务时才可以删除。;  ''',
        description='''
            ; 删除一个私有镜像。; ; 详细操作说明请参考帮助文档：[删除私有镜像](https://docs.jdcloud.com/cn/virtual-machines/delete-private-image); ; ## 接口说明; - 已共享的私有镜像在取消共享关系前不可以删除，如私有镜像已共享给其他用户，请取消共享后再进行删除。; - 本地系统盘镜像在有基于其创建的云主机时，将无法删除。; - 只能操作私有镜像。; - 私有镜像没有正在处理中的任务时才可以删除。; 。

            示例: jdc vm delete-image  --image-id xxx
        ''',
    )
    def delete_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DeleteImageRequest import DeleteImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DeleteImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-source'], dict(help="""(string) 镜像来源，如果没有指定 `ids` 参数，此参数必传。取值范围：; `public`：官方镜像。; `thirdparty`：镜像市场镜像。; `private`：用户自己的私有镜像。; `shared`：其他用户分享的镜像。; `community`：社区镜像。;  """, dest='imageSource',  required=False)),
            (['--offline'], dict(help="""(bool) 查询已经下线的镜像时使用。; 只有查询 `官方镜像` 或者 `镜像市场镜像` 时，此参数才有意义，其它情况下此参数无效。; 指定 `ids` 查询时，此参数无效。;  """, dest='offline', type=bool, required=False)),
            (['--platform'], dict(help="""(string) 根据镜像的操作系统发行版查询。; 取值范围：`Ubuntu、CentOS、Windows Server`。;  """, dest='platform',  required=False)),
            (['--ids'], dict(help="""(array: string) 指定镜像ID查询，如果指定了此参数，其它参数可以不传。;  """, dest='ids',  required=False)),
            (['--image-name'], dict(help="""(string) 根据镜像名称模糊查询。 """, dest='imageName',  required=False)),
            (['--root-device-type'], dict(help="""(string) 根据镜像支持的系统盘类型查询。支持范围：`localDisk` 本地系统盘镜像；`cloudDisk` 云盘系统盘镜像。 """, dest='rootDeviceType',  required=False)),
            (['--launch-permission'], dict(help="""(string) 根据镜像的使用权限查询，可选参数，仅当 `imageSource` 为 `private` 时有效。取值范围：; `all`：没有限制，所有人均可以使用。; `specifiedUsers`：只有共享用户可以使用。; `ownerOnly`：镜像拥有者自己可以使用。;  """, dest='launchPermission',  required=False)),
            (['--status'], dict(help="""(string) 根据镜像状态查询。参考 [镜像状态](https://docs.jdcloud.com/virtual-machines/api/image_status) """, dest='status',  required=False)),
            (['--service-code'], dict(help="""(string) 已废弃。 """, dest='serviceCode',  required=False)),
            (['--architecture'], dict(help="""(string) CPU架构。支持范围：`x86_64`、`arm64`。 """, dest='architecture',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询镜像信息列表。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 通过此接口可以查询到京东云官方镜像、第三方镜像、镜像市场、私有镜像、或其他用户共享给您的镜像。; - 请求参数即过滤条件，每个条件之间的关系为逻辑与（AND）的关系。; - 如果使用子帐号查询，只会查询到该子帐号有权限的镜像。关于资源权限请参考 [IAM概述](https://docs.jdcloud.com/cn/iam/product-overview)。; - 单次查询最大可查询100条镜像信息。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。;  ''',
        description='''
            ; 查询镜像信息列表。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 通过此接口可以查询到京东云官方镜像、第三方镜像、镜像市场、私有镜像、或其他用户共享给您的镜像。; - 请求参数即过滤条件，每个条件之间的关系为逻辑与（AND）的关系。; - 如果使用子帐号查询，只会查询到该子帐号有权限的镜像。关于资源权限请参考 [IAM概述](https://docs.jdcloud.com/cn/iam/product-overview)。; - 单次查询最大可查询100条镜像信息。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。; 。

            示例: jdc vm describe-images 
        ''',
    )
    def describe_images(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeImagesRequest import DescribeImagesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeImagesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询单个镜像的实例规格限制。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 该接口与批量查询镜像的实例规格限制返回的信息一致。; - 通过此接口可以查询镜像的实例规格限制信息。; - 只有官方镜像、第三方镜像有实例规格的限制，用户的私有镜像没有此限制。;  ''',
        description='''
            ; 查询单个镜像的实例规格限制。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 该接口与批量查询镜像的实例规格限制返回的信息一致。; - 通过此接口可以查询镜像的实例规格限制信息。; - 只有官方镜像、第三方镜像有实例规格的限制，用户的私有镜像没有此限制。; 。

            示例: jdc vm describe-image-constraints  --image-id xxx
        ''',
    )
    def describe_image_constraints(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeImageConstraintsRequest import DescribeImageConstraintsRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeImageConstraintsRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--ids'], dict(help="""(array: string) 要查询的镜像ID列表，只支持官方镜像和第三方镜像。 """, dest='ids',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 批量查询镜像的实例规格限制。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 通过此接口可以查询镜像的实例规格限制信息。; - 只有官方镜像、第三方镜像有实例规格的限制，用户的私有镜像没有此限制。;  ''',
        description='''
            ; 批量查询镜像的实例规格限制。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 通过此接口可以查询镜像的实例规格限制信息。; - 只有官方镜像、第三方镜像有实例规格的限制，用户的私有镜像没有此限制。; 。

            示例: jdc vm describe-image-constraints-batch 
        ''',
    )
    def describe_image_constraints_batch(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeImageConstraintsBatchRequest import DescribeImageConstraintsBatchRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeImageConstraintsBatchRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--pins'], dict(help="""(array: string) 共享的目标京东云帐户列表。 """, dest='pins',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 共享私有镜像。; ; 详细操作说明请参考帮助文档：[共享私有镜像](https://docs.jdcloud.com/cn/virtual-machines/share-image); ; ## 接口说明; - 只允许共享用户的私有镜像。; - 单个镜像最多可以共享给20个京东云帐户、不可以共享给自己。; - 带有加密快照的打包镜像无法共享。;  ''',
        description='''
            ; 共享私有镜像。; ; 详细操作说明请参考帮助文档：[共享私有镜像](https://docs.jdcloud.com/cn/virtual-machines/share-image); ; ## 接口说明; - 只允许共享用户的私有镜像。; - 单个镜像最多可以共享给20个京东云帐户、不可以共享给自己。; - 带有加密快照的打包镜像无法共享。; 。

            示例: jdc vm share-image  --image-id xxx
        ''',
    )
    def share_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ShareImageRequest import ShareImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ShareImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--pins'], dict(help="""(array: string) 需要取消的京东云帐户列表。 """, dest='pins',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 取消共享私有镜像。; ; 详细操作说明请参考帮助文档：[取消共享私有镜像](https://docs.jdcloud.com/cn/virtual-machines/cancel-share-image); ; ## 接口说明; - 只允许操作用户的私有镜像。; - 原被共享用户将无法再使用该镜像创建云主机实例，同时使用该镜像创建的云主机实例也无法重置为原始系统状态。;  ''',
        description='''
            ; 取消共享私有镜像。; ; 详细操作说明请参考帮助文档：[取消共享私有镜像](https://docs.jdcloud.com/cn/virtual-machines/cancel-share-image); ; ## 接口说明; - 只允许操作用户的私有镜像。; - 原被共享用户将无法再使用该镜像创建云主机实例，同时使用该镜像创建的云主机实例也无法重置为原始系统状态。; 。

            示例: jdc vm un-share-image  --image-id xxx
        ''',
    )
    def un_share_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.UnShareImageRequest import UnShareImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = UnShareImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 发布社区镜像。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 只允许发布用户的私有镜像。; - 仅支持云盘系统盘的私有镜像。; - 带有加密快照的打包镜像无法发布为社区镜像。; - 发布为社区镜像后会撤销共享关系。;  ''',
        description='''
            ; 发布社区镜像。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 只允许发布用户的私有镜像。; - 仅支持云盘系统盘的私有镜像。; - 带有加密快照的打包镜像无法发布为社区镜像。; - 发布为社区镜像后会撤销共享关系。; 。

            示例: jdc vm release-image  --image-id xxx
        ''',
    )
    def release_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ReleaseImageRequest import ReleaseImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ReleaseImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 撤销社区镜像。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 只允许撤销用户的私有镜像。;  ''',
        description='''
            ; 撤销社区镜像。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 只允许撤销用户的私有镜像。; 。

            示例: jdc vm un-release-image  --image-id xxx
        ''',
    )
    def un_release_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.UnReleaseImageRequest import UnReleaseImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = UnReleaseImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询私有镜像共享给哪些京东云帐户。; ; 详细操作说明请参考帮助文档：[共享私有镜像](https://docs.jdcloud.com/cn/virtual-machines/share-image); ; ## 接口说明; - 只允许查询用户的私有镜像。;  ''',
        description='''
            ; 查询私有镜像共享给哪些京东云帐户。; ; 详细操作说明请参考帮助文档：[共享私有镜像](https://docs.jdcloud.com/cn/virtual-machines/share-image); ; ## 接口说明; - 只允许查询用户的私有镜像。; 。

            示例: jdc vm describe-image-members  --image-id xxx
        ''',
    )
    def describe_image_members(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeImageMembersRequest import DescribeImageMembersRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeImageMembersRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--source-image-ids'], dict(help="""(array: string) 要复制的私有镜像ID列表，最多支持10个。 """, dest='sourceImageIds',  required=False)),
            (['--destination-region'], dict(help="""(string) 目标地域。 """, dest='destinationRegion',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 镜像跨地域复制。; ; 详细操作说明请参考帮助文档：[镜像复制](https://docs.jdcloud.com/cn/virtual-machines/copy-image); ; ## 接口说明; - 调用该接口将私有镜像复制到其它地域下。; - 只支持云盘系统盘的镜像。; - 不支持带有加密快照的镜像。;  ''',
        description='''
            ; 镜像跨地域复制。; ; 详细操作说明请参考帮助文档：[镜像复制](https://docs.jdcloud.com/cn/virtual-machines/copy-image); ; ## 接口说明; - 调用该接口将私有镜像复制到其它地域下。; - 只支持云盘系统盘的镜像。; - 不支持带有加密快照的镜像。; 。

            示例: jdc vm copy-images  --destination-region xxx
        ''',
    )
    def copy_images(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.CopyImagesRequest import CopyImagesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = CopyImagesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--name'], dict(help="""(string) 镜像名称。参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='name',  required=False)),
            (['--description'], dict(help="""(string) 镜像描述。参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='description',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改镜像属性。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 只支持修改镜像名称或描述。;  ''',
        description='''
            ; 修改镜像属性。; ; 详细操作说明请参考帮助文档：[镜像概述](https://docs.jdcloud.com/cn/virtual-machines/image-overview); ; ## 接口说明; - 只支持修改镜像名称或描述。; 。

            示例: jdc vm modify-image-attribute  --image-id xxx
        ''',
    )
    def modify_image_attribute(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyImageAttributeRequest import ModifyImageAttributeRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyImageAttributeRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--architecture'], dict(help="""(string) 镜像架构。取值范围：`x86_64、arm64`。 """, dest='architecture',  required=True)),
            (['--os-type'], dict(help="""(string) 镜像的操作系统类型。取值范围：`windows、linux`。 """, dest='osType',  required=True)),
            (['--platform'], dict(help="""(string) 镜像的操作系统平台名称。; 取值范围：`Ubuntu、CentOS、Windows Server、Other Linux、Other Windows`。;  """, dest='platform',  required=True)),
            (['--disk-format'], dict(help="""(string) 磁盘格式，取值范围：`qcow2、vhd、vmdk、raw`。 """, dest='diskFormat',  required=True)),
            (['--system-disk-size-gb'], dict(help="""(int) 以此镜像需要制作的系统盘的默认大小，单位GB。最小值40，最大值500，要求值是10的整数倍。 """, dest='systemDiskSizeGB', type=int, required=True)),
            (['--image-url'], dict(help="""(string) 要导入镜像的对象存储外链地址。 """, dest='imageUrl',  required=True)),
            (['--os-version'], dict(help="""(string) 镜像的操作系统版本。 """, dest='osVersion',  required=False)),
            (['--image-name'], dict(help="""(string) 导入镜像的自定义名称。参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='imageName',  required=True)),
            (['--description'], dict(help="""(string) 导入镜像的描述信息。参考 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。 """, dest='description',  required=False)),
            (['--force-import'], dict(help="""(bool) 是否强制导入。强制导入会忽略镜像的合规性检测。默认为false。 """, dest='forceImport', type=bool, required=False)),
            (['--client-token'], dict(help="""(string) 用户导出镜像的幂等性保证。每次导出请传入不同的值，如果传值与某次的clientToken相同，则返还同一个请求结果，不能超过64个字符。 """, dest='clientToken',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 导入私有镜像。; ; 详细操作说明请参考帮助文档：[导入私有镜像](https://docs.jdcloud.com/cn/virtual-machines/import-private-image); ; ## 接口说明; - 当前仅支持导入系统盘镜像。; - 导入后的镜像将以 `云硬盘系统盘镜像` 格式作为私有镜像使用，同时会自动生成一个与导入镜像关联的快照。;  ''',
        description='''
            ; 导入私有镜像。; ; 详细操作说明请参考帮助文档：[导入私有镜像](https://docs.jdcloud.com/cn/virtual-machines/import-private-image); ; ## 接口说明; - 当前仅支持导入系统盘镜像。; - 导入后的镜像将以 `云硬盘系统盘镜像` 格式作为私有镜像使用，同时会自动生成一个与导入镜像关联的快照。; 。

            示例: jdc vm import-image  --architecture xxx --os-type xxx --platform xxx --disk-format xxx --system-disk-size-gb 5 --image-url xxx --image-name xxx
        ''',
    )
    def import_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ImportImageRequest import ImportImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ImportImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。 """, dest='imageId',  required=True)),
            (['--role-name'], dict(help="""(string) 用户创建的服务角色名称。 """, dest='roleName',  required=True)),
            (['--oss-url'], dict(help="""(string) 存储导出镜像文件的 `oss bucket` 的域名，请填写以 https:// 开头的完整url。 """, dest='ossUrl',  required=True)),
            (['--oss-prefix'], dict(help="""(string) 导出镜像文件名前缀，仅支持英文字母和数字，不能超过32个字符。 """, dest='ossPrefix',  required=False)),
            (['--client-token'], dict(help="""(string) 用户导出镜像的幂等性保证。每次导出请传入不同的值，如果传值与某次的clientToken相同，则返还同一个请求结果，不能超过64个字符。 """, dest='clientToken',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 导出私有镜像。; ; 将京东云私有镜像导出至京东云以外环境。; ; 详细操作说明请参考帮助文档：[导出私有镜像](https://docs.jdcloud.com/cn/virtual-machines/export-private-image); ; ## 接口说明; - 调用此接口将私有镜像导出到京东云对象存储空间中。; - 仅支持系统盘镜像导出，即使镜像有关联的数据盘快照，也仅会导出系统盘镜像文件。; - 导出的镜像文件格式为QCOW2。; - `Windows Server` 操作系统的镜像不支持导出（若镜像来源为导入镜像，则无此限制）。; - 镜像必须为 `云硬盘系统盘` 镜像，如您的镜像是 `本地盘系统盘` 镜像，可以通过镜像类型转换功能转换为云盘系统盘镜像后再导出。;  ''',
        description='''
            ; 导出私有镜像。; ; 将京东云私有镜像导出至京东云以外环境。; ; 详细操作说明请参考帮助文档：[导出私有镜像](https://docs.jdcloud.com/cn/virtual-machines/export-private-image); ; ## 接口说明; - 调用此接口将私有镜像导出到京东云对象存储空间中。; - 仅支持系统盘镜像导出，即使镜像有关联的数据盘快照，也仅会导出系统盘镜像文件。; - 导出的镜像文件格式为QCOW2。; - `Windows Server` 操作系统的镜像不支持导出（若镜像来源为导入镜像，则无此限制）。; - 镜像必须为 `云硬盘系统盘` 镜像，如您的镜像是 `本地盘系统盘` 镜像，可以通过镜像类型转换功能转换为云盘系统盘镜像后再导出。; 。

            示例: jdc vm export-image  --image-id xxx --role-name xxx --oss-url xxx
        ''',
    )
    def export_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ExportImageRequest import ExportImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ExportImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--task-action'], dict(help="""(string) 任务操作类型。支持范围：`ImportImage、ExportImage`。 """, dest='taskAction',  required=False)),
            (['--task-ids'], dict(help="""(array: string) 任务id列表。 """, dest='taskIds',  required=False)),
            (['--task-status'], dict(help="""(string) 任务状态。支持范围：`pending、running、failed、finished`。 """, dest='taskStatus',  required=False)),
            (['--start-time'], dict(help="""(string) 任务开始时间 """, dest='startTime',  required=False)),
            (['--end-time'], dict(help="""(string) 任务结束时间 """, dest='endTime',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询镜像任务详情。; ; 将京东云私有镜像导出至京东云以外环境。; ; 详细操作说明请参考帮助文档：; [导入私有镜像](https://docs.jdcloud.com/cn/virtual-machines/import-private-image); [导出私有镜像](https://docs.jdcloud.com/cn/virtual-machines/export-private-image); ; ## 接口说明; - 调用该接口可查询镜像导入或导出的任务详情。;  ''',
        description='''
            ; 查询镜像任务详情。; ; 将京东云私有镜像导出至京东云以外环境。; ; 详细操作说明请参考帮助文档：; [导入私有镜像](https://docs.jdcloud.com/cn/virtual-machines/import-private-image); [导出私有镜像](https://docs.jdcloud.com/cn/virtual-machines/export-private-image); ; ## 接口说明; - 调用该接口可查询镜像导入或导出的任务详情。; 。

            示例: jdc vm image-tasks 
        ''',
    )
    def image_tasks(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ImageTasksRequest import ImageTasksRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ImageTasksRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `resourceTypes`: 资源类型，支持多个，可选范围：`instance、instance_cpu、instance_memory、instance_local_disk、keypair、image、instanceTemplate、imageShare`;  """, dest='filters',  required=False)),
            (['--image-id'], dict(help="""(string) 私有镜像Id。; 查询镜像共享 `imageShare` 的配额时，此参数必传。;  """, dest='imageId',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询资源配额。; ; ## 接口说明; - 调用该接口可查询 `云主机`、`云主机的CPU`、`云主机的内存`、`云主机的本地盘`、`镜像`、`密钥`、`实例模板`、`镜像共享` 的配额。;  ''',
        description='''
            ; 查询资源配额。; ; ## 接口说明; - 调用该接口可查询 `云主机`、`云主机的CPU`、`云主机的内存`、`云主机的本地盘`、`镜像`、`密钥`、`实例模板`、`镜像共享` 的配额。; 。

            示例: jdc vm describe-quotas 
        ''',
    )
    def describe_quotas(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeQuotasRequest import DescribeQuotasRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeQuotasRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--tags'], dict(help="""(array: tagFilter) Tag筛选条件。 """, dest='tags',  required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceId`: 云主机ID，精确匹配，支持多个; `privateIpAddress`: 云主机挂载的网卡内网主IP地址，模糊匹配，支持多个; `az`: 可用区，精确匹配，支持多个; `vpcId`: 私有网络ID，精确匹配，支持多个; `status`: 云主机状态，精确匹配，支持多个，参考 [云主机状态](https://docs.jdcloud.com/virtual-machines/api/vm_status); `name`: 云主机名称，模糊匹配，支持单个; `imageId`: 镜像ID，精确匹配，支持多个; `networkInterfaceId`: 弹性网卡ID，精确匹配，支持多个; `subnetId`: 子网ID，精确匹配，支持多个; `agId`: 使用可用组id，支持单个; `faultDomain`: 错误域，支持多个; `dedicatedHostId`: 专有宿主机ID，精确匹配，支持多个; `dedicatedPoolId`: 专有宿主机池ID，精确匹配，支持多个; `instanceType`: 实例规格，精确匹配，支持多个，可通过查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得实例规格; `elasticIpAddress`: 公网IP地址，精确匹配，支持单个。该条件会将公网IP转换成 `networkInterfaceId` 进行查询，所以与 `networkInterfaceId` 为或者的关系。;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询一台或多台云主机实例的详细信息。; ; 详细操作说明请参考帮助文档：[查找实例](https://docs.jdcloud.com/cn/virtual-machines/search-instance); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 如果使用子帐号查询，只会查询到该子帐号有权限的云主机实例。关于资源权限请参考 [IAM概述](https://docs.jdcloud.com/cn/iam/product-overview)。; - 单次查询最大可查询100条云主机实例数据。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。;  ''',
        description='''
            ; 查询一台或多台云主机实例的详细信息。; ; 详细操作说明请参考帮助文档：[查找实例](https://docs.jdcloud.com/cn/virtual-machines/search-instance); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 如果使用子帐号查询，只会查询到该子帐号有权限的云主机实例。关于资源权限请参考 [IAM概述](https://docs.jdcloud.com/cn/iam/product-overview)。; - 单次查询最大可查询100条云主机实例数据。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。; 。

            示例: jdc vm describe-instances 
        ''',
    )
    def describe_instances(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstancesRequest import DescribeInstancesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstancesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-spec'], dict(help="""(instanceSpec) 实例配置。;  """, dest='instanceSpec',  required=True)),
            (['--max-count'], dict(help="""(int) 创建实例的数量，不能超过用户配额。; 取值范围：[1,100]；默认值：1。; 如果在弹性网卡中指定了内网IP地址，那么单次创建 `maxCount` 只能是 1。;  """, dest='maxCount', type=int, required=False)),
            (['--client-token'], dict(help="""(string) 用于保证请求的幂等性。由客户端生成，并确保不同请求中该参数唯一，长度不能超过64个字符。;  """, dest='clientToken',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 创建一台或多台指定配置的云主机实例。; ; 实例有三种创建方式，不同方式下传参详见下方的请求[参数说明](createInstance#requestparameters)，也可参考请求[示例](createInstance#examples)。; ; 1、自定义创建：按配置要求逐一指定参数创建；; 2、使用实例模板创建：[实例模板](https://docs.jdcloud.com/virtual-machines/instance-template-overview)是实例配置信息的预配置，通过实例模板可快速创建实例，省去逐一配置参数的步骤。指定实例模板创建时，如不额外指定模板包含的参数将以模板为准创建实例，模板中未包含的参数，如可用区、内网IPv4地址、名称等仍需指定；; 3、基于高可用组创建：[高可用组](https://docs.jdcloud.com/availability-group/product-overview)是一种高可用部署解决方案，提供了组内实例在数据中心内横跨多个故障域均衡部署的机制。高可用组须搭配实例模板使用，基于高可用组创建的实例将在其指定的可用区内以实例模板配置按一定分散机制创建实例。此创建方式下，实例创建参数除内网IPv4地址、名称等外均以实例模板为准且不支持再次指定。; ; 详细操作说明请参考帮助文档：[创建实例](https://docs.jdcloud.com/cn/virtual-machines/create-instance); ; ## 接口说明; - 创建实例前，请参考 [创建前准备](https://docs.jdcloud.com/virtual-machines/account-preparation-linux) 完成实名认证、支付方式确认、计费类型选择等准备工作。; - 创建实例的配置说明和选择指导，请参考 [配置项说明](https://docs.jdcloud.com/cn/virtual-machines/select-configuration-linux)。; - 各地域下实例及关联资源（云硬盘、弹性公网IP）的可创建数量受配额限制，创建前请通过 [DescribeQuotas](https://docs.jdcloud.com/cn/virtual-machines/api/describequotas?content=API) 确认配额，如须提升请[提交工单](https://ticket.jdcloud.com/applyorder/submit)或联系京东云客服。; - 不同地域及可用区下售卖的实例规格有差异，可通过 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes?content=API) 查询在售规格及规格详细信息。; - 通过本接口创建包年包月实例时将自动从账户扣款（代金券优先），如需使用第三方支付方式请通过控制台创建。; - 单次请求最多支持创建 `100` 台实例。; - 本接口为异步接口，请求下发成功后会返回RequestId和实例ID，此时实例处于 `Pending`（创建中）状态。如创建成功则实例自动变为 `Running`（运行中）状态；如创建失败则短暂处于 `Error`（错误）状态，随后将自动删除（创建失败的实例不会收费且会自动释放占用的配额）。实例状态可以通过 [describeInstanceStatus](https://docs.jdcloud.com/virtual-machines/api/describeinstancestatus?content=API) 接口查询。; - 批量创建多台实例时系统将尽可能完成目标创建数量，但受底层资源、配额等因素影响，可能存在部分成功部分失败的情况，还请关注最终完成数量，如有失败情况请尝试重新申请或联系客服。;  ''',
        description='''
            ; 创建一台或多台指定配置的云主机实例。; ; 实例有三种创建方式，不同方式下传参详见下方的请求[参数说明](createInstance#requestparameters)，也可参考请求[示例](createInstance#examples)。; ; 1、自定义创建：按配置要求逐一指定参数创建；; 2、使用实例模板创建：[实例模板](https://docs.jdcloud.com/virtual-machines/instance-template-overview)是实例配置信息的预配置，通过实例模板可快速创建实例，省去逐一配置参数的步骤。指定实例模板创建时，如不额外指定模板包含的参数将以模板为准创建实例，模板中未包含的参数，如可用区、内网IPv4地址、名称等仍需指定；; 3、基于高可用组创建：[高可用组](https://docs.jdcloud.com/availability-group/product-overview)是一种高可用部署解决方案，提供了组内实例在数据中心内横跨多个故障域均衡部署的机制。高可用组须搭配实例模板使用，基于高可用组创建的实例将在其指定的可用区内以实例模板配置按一定分散机制创建实例。此创建方式下，实例创建参数除内网IPv4地址、名称等外均以实例模板为准且不支持再次指定。; ; 详细操作说明请参考帮助文档：[创建实例](https://docs.jdcloud.com/cn/virtual-machines/create-instance); ; ## 接口说明; - 创建实例前，请参考 [创建前准备](https://docs.jdcloud.com/virtual-machines/account-preparation-linux) 完成实名认证、支付方式确认、计费类型选择等准备工作。; - 创建实例的配置说明和选择指导，请参考 [配置项说明](https://docs.jdcloud.com/cn/virtual-machines/select-configuration-linux)。; - 各地域下实例及关联资源（云硬盘、弹性公网IP）的可创建数量受配额限制，创建前请通过 [DescribeQuotas](https://docs.jdcloud.com/cn/virtual-machines/api/describequotas?content=API) 确认配额，如须提升请[提交工单](https://ticket.jdcloud.com/applyorder/submit)或联系京东云客服。; - 不同地域及可用区下售卖的实例规格有差异，可通过 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes?content=API) 查询在售规格及规格详细信息。; - 通过本接口创建包年包月实例时将自动从账户扣款（代金券优先），如需使用第三方支付方式请通过控制台创建。; - 单次请求最多支持创建 `100` 台实例。; - 本接口为异步接口，请求下发成功后会返回RequestId和实例ID，此时实例处于 `Pending`（创建中）状态。如创建成功则实例自动变为 `Running`（运行中）状态；如创建失败则短暂处于 `Error`（错误）状态，随后将自动删除（创建失败的实例不会收费且会自动释放占用的配额）。实例状态可以通过 [describeInstanceStatus](https://docs.jdcloud.com/virtual-machines/api/describeinstancestatus?content=API) 接口查询。; - 批量创建多台实例时系统将尽可能完成目标创建数量，但受底层资源、配额等因素影响，可能存在部分成功部分失败的情况，还请关注最终完成数量，如有失败情况请尝试重新申请或联系客服。; 。

            示例: jdc vm create-instances  --instance-spec '{"":""}'
        ''',
    )
    def create_instances(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.CreateInstancesRequest import CreateInstancesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = CreateInstancesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--tags'], dict(help="""(array: tagFilter) Tag筛选条件 """, dest='tags',  required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceId`: 云主机ID，精确匹配，支持多个; `privateIpAddress`: 云主机挂载的网卡内网主IP地址，模糊匹配，支持多个; `az`: 可用区，精确匹配，支持多个; `vpcId`: 私有网络ID，精确匹配，支持多个; `status`: 云主机状态，精确匹配，支持多个，参考 [云主机状态](https://docs.jdcloud.com/virtual-machines/api/vm_status); `name`: 云主机名称，模糊匹配，支持单个; `imageId`: 镜像ID，精确匹配，支持多个; `networkInterfaceId`: 弹性网卡ID，精确匹配，支持多个; `subnetId`: 子网ID，精确匹配，支持多个; `agId`: 使用可用组id，支持单个; `faultDomain`: 错误域，支持多个; `dedicatedHostId`: 专有宿主机ID，精确匹配，支持多个; `dedicatedPoolId`: 专有宿主机池ID，精确匹配，支持多个; `instanceType`: 实例规格，精确匹配，支持多个，可通过查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得实例规格; `elasticIpAddress`: 公网IP地址，精确匹配，支持单个。该条件会将公网IP转换成 `networkInterfaceId` 进行查询，所以与 `networkInterfaceId` 为或者的关系。;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询一台或多台云主机实例的详细信息。该接口为轻量级接口，不返回云盘、网络、计费、标签等关联信息。如果不需要关联资源属性，尽量选择使用该接口。; ; 详细操作说明请参考帮助文档：[查找实例](https://docs.jdcloud.com/cn/virtual-machines/search-instance); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 如果使用子帐号查询，只会查询到该子帐号有权限的云主机实例。关于资源权限请参考 [IAM概述](https://docs.jdcloud.com/cn/iam/product-overview)。; - 单次查询最大可查询100条云主机实例数据。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。;  ''',
        description='''
            ; 查询一台或多台云主机实例的详细信息。该接口为轻量级接口，不返回云盘、网络、计费、标签等关联信息。如果不需要关联资源属性，尽量选择使用该接口。; ; 详细操作说明请参考帮助文档：[查找实例](https://docs.jdcloud.com/cn/virtual-machines/search-instance); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 如果使用子帐号查询，只会查询到该子帐号有权限的云主机实例。关于资源权限请参考 [IAM概述](https://docs.jdcloud.com/cn/iam/product-overview)。; - 单次查询最大可查询100条云主机实例数据。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。; 。

            示例: jdc vm describe-brief-instances 
        ''',
    )
    def describe_brief_instances(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeBriefInstancesRequest import DescribeBriefInstancesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeBriefInstancesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询一台云主机实例的详细信息。; ; 详细操作说明请参考帮助文档：[查找实例](https://docs.jdcloud.com/cn/virtual-machines/search-instance); ; ## 接口说明; - 该接口与查询云主机列表返回的信息一致。; - 只需要查询单个云主机实例详细信息的时候可以调用该接口。;  ''',
        description='''
            ; 查询一台云主机实例的详细信息。; ; 详细操作说明请参考帮助文档：[查找实例](https://docs.jdcloud.com/cn/virtual-machines/search-instance); ; ## 接口说明; - 该接口与查询云主机列表返回的信息一致。; - 只需要查询单个云主机实例详细信息的时候可以调用该接口。; 。

            示例: jdc vm describe-instance  --instance-id xxx
        ''',
    )
    def describe_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceRequest import DescribeInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 删除一台云主机实例。; ; 详细操作说明请参考帮助文档：[删除实例](https://docs.jdcloud.com/cn/virtual-machines/delete-instance); ; ## 接口说明; - 不可以删除包年包月未到期的云主机。如果云主机为包年包月已到期的，并且用户处于白名单中，也不允许删除。; - 不可以删除没有计费信息的云主机，该情况只限于创建过程中出现了异常。; - 云主机状态必须为运行 `running`、停止 `stopped`、错误 `error`、状态，同时云主机没有正在进行中的任务才可以删除。; - 如果云主机中挂载的数据盘为按配置计费的云硬盘且 `AutoDelete` 属性为 `true`，那么数据盘会随云主机一起删除。; - 云主机中绑定的弹性公网IP不会随云主机一起删除，如果不需要保留，需要单独进行删除，需要使用者注意。; - 如出现不能删除的情况请 [提交工单](https://ticket.jdcloud.com/applyorder/submit) 或联系京东云客服。;  [MFA enabled] ''',
        description='''
            ; 删除一台云主机实例。; ; 详细操作说明请参考帮助文档：[删除实例](https://docs.jdcloud.com/cn/virtual-machines/delete-instance); ; ## 接口说明; - 不可以删除包年包月未到期的云主机。如果云主机为包年包月已到期的，并且用户处于白名单中，也不允许删除。; - 不可以删除没有计费信息的云主机，该情况只限于创建过程中出现了异常。; - 云主机状态必须为运行 `running`、停止 `stopped`、错误 `error`、状态，同时云主机没有正在进行中的任务才可以删除。; - 如果云主机中挂载的数据盘为按配置计费的云硬盘且 `AutoDelete` 属性为 `true`，那么数据盘会随云主机一起删除。; - 云主机中绑定的弹性公网IP不会随云主机一起删除，如果不需要保留，需要单独进行删除，需要使用者注意。; - 如出现不能删除的情况请 [提交工单](https://ticket.jdcloud.com/applyorder/submit) 或联系京东云客服。;  [MFA enabled]。

            示例: jdc vm delete-instance  --instance-id xxx
        ''',
    )
    def delete_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DeleteInstanceRequest import DeleteInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DeleteInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceId`: 云主机ID，精确匹配，支持多个; `privateIpAddress`: 主网卡内网主IP地址，模糊匹配，支持多个; `vpcId`: 私有网络ID，精确匹配，支持多个; `status`: 云主机状态，精确匹配，支持多个，参考 [云主机状态](https://docs.jdcloud.com/virtual-machines/api/vm_status); `name`: 云主机名称，模糊匹配，支持单个; `imageId`: 镜像ID，精确匹配，支持多个; `agId`: 使用可用组id，支持单个; `faultDomain`: 错误域，支持多个; `networkInterfaceId`: 弹性网卡ID，精确匹配，支持多个; `subnetId`: 子网ID，精确匹配，支持多个;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询一台或多台云主机实例的状态。; ; 云主机实例的状态说明请参考帮助文档：[云主机状态](https://docs.jdcloud.com/cn/virtual-machines/api/vm_status); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条云主机状态。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。;  ''',
        description='''
            ; 查询一台或多台云主机实例的状态。; ; 云主机实例的状态说明请参考帮助文档：[云主机状态](https://docs.jdcloud.com/cn/virtual-machines/api/vm_status); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条云主机状态。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。; 。

            示例: jdc vm describe-instance-status 
        ''',
    )
    def describe_instance_status(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceStatusRequest import DescribeInstanceStatusRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceStatusRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；<br>默认为20；取值范围[10, 100]。 """, dest='pageSize', type=int, required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceId`: 云主机ID，精确匹配，支持多个; `privateIpAddress`: 主网卡内网主IP地址，模糊匹配，支持多个; `vpcId`: 私有网络ID，精确匹配，支持多个; `status`: 云主机状态，精确匹配，支持多个，参考 [云主机状态](https://docs.jdcloud.com/virtual-machines/api/vm_status); `name`: 云主机名称，模糊匹配，支持单个; `imageId`: 镜像ID，精确匹配，支持多个; `agId`: 使用可用组id，支持单个; `faultDomain`: 错误域，支持多个; `networkInterfaceId`: 弹性网卡ID，精确匹配，支持多个; `subnetId`: 子网ID，精确匹配，支持多个;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询一台或多台云主机实例的主网卡内网主IP地址。; ; 弹性网卡说明请参考帮助文档：[弹性网卡](https://docs.jdcloud.com/cn/virtual-machines/attach-eni); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条云主机实例数据。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。;  ''',
        description='''
            ; 查询一台或多台云主机实例的主网卡内网主IP地址。; ; 弹性网卡说明请参考帮助文档：[弹性网卡](https://docs.jdcloud.com/cn/virtual-machines/attach-eni); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询100条云主机实例数据。; - 尽量一次调用接口查询多条数据，不建议使用该批量查询接口一次查询一条数据，如果使用不当导致查询过于密集，可能导致网关触发限流。; - 由于该接口为 `GET` 方式请求，最终参数会转换为 `URL` 上的参数，但是 `HTTP` 协议下的 `GET` 请求参数长度是有大小限制的，使用者需要注意参数超长的问题。; 。

            示例: jdc vm describe-instance-private-ip-address 
        ''',
    )
    def describe_instance_private_ip_address(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstancePrivateIpAddressRequest import DescribeInstancePrivateIpAddressRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstancePrivateIpAddressRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--charge-on-stopped'], dict(help="""(string) 停机不计费模式。; 该参数仅对按配置计费且系统盘为云硬盘的实例生效，并且不是专有宿主机中的实例。; 配置停机不计费且停机后，实例部分将停止计费，且释放实例自身包含的资源（CPU/内存/GPU/本地数据盘）。; 可选值：; `keepCharging`：停机后保持计费，不释放资源。; `stopCharging`：停机后停止计费，释放实例资源。默认值为空。;  """, dest='chargeOnStopped',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 停止云主机实例。; ; 详细操作说明请参考帮助文档：[停止实例](https://docs.jdcloud.com/cn/virtual-machines/stop-instance); ; ## 接口说明; - 实例状态必须为运行 `running` 状态，同时实例没有正在进行中的任务时才可停止。; - 如果云主机实例属性 `chargeOnStopped` 的值为 `stopCharging`，实例关机之后，实例部分将停止计费，且释放实例自身包含的资源（CPU/内存/GPU/本地数据盘）。需要使用者注意的是，实例一旦释放自身资源，再次启动时有可能因为库存资源不足而导致无法启动。; - `chargeOnStopped` 该参数仅对按配置计费且系统盘为云硬盘的实例生效，并且不是专有宿主机中的实例。;  ''',
        description='''
            ; 停止云主机实例。; ; 详细操作说明请参考帮助文档：[停止实例](https://docs.jdcloud.com/cn/virtual-machines/stop-instance); ; ## 接口说明; - 实例状态必须为运行 `running` 状态，同时实例没有正在进行中的任务时才可停止。; - 如果云主机实例属性 `chargeOnStopped` 的值为 `stopCharging`，实例关机之后，实例部分将停止计费，且释放实例自身包含的资源（CPU/内存/GPU/本地数据盘）。需要使用者注意的是，实例一旦释放自身资源，再次启动时有可能因为库存资源不足而导致无法启动。; - `chargeOnStopped` 该参数仅对按配置计费且系统盘为云硬盘的实例生效，并且不是专有宿主机中的实例。; 。

            示例: jdc vm stop-instance  --instance-id xxx
        ''',
    )
    def stop_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.StopInstanceRequest import StopInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = StopInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 启动云主机实例。; ; 详细操作说明请参考帮助文档：[启动实例](https://docs.jdcloud.com/cn/virtual-machines/start-instance); ; ## 接口说明; - 实例状态必须为停止 `stopped` 状态，同时实例没有正在进行中的任务时才可以启动。; - 如果实例为停机不计费模式，启动时有可能因为库存资源不足而导致无法启动。; - 如果云主机实例已欠费或已到期，则无法启动。; - 如果实例系统盘是云硬盘，启动之前请确保系统盘处于正常挂载状态。;  ''',
        description='''
            ; 启动云主机实例。; ; 详细操作说明请参考帮助文档：[启动实例](https://docs.jdcloud.com/cn/virtual-machines/start-instance); ; ## 接口说明; - 实例状态必须为停止 `stopped` 状态，同时实例没有正在进行中的任务时才可以启动。; - 如果实例为停机不计费模式，启动时有可能因为库存资源不足而导致无法启动。; - 如果云主机实例已欠费或已到期，则无法启动。; - 如果实例系统盘是云硬盘，启动之前请确保系统盘处于正常挂载状态。; 。

            示例: jdc vm start-instance  --instance-id xxx
        ''',
    )
    def start_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.StartInstanceRequest import StartInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = StartInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 重启云主机实例。; ; 详细操作说明请参考帮助文档：[重启实例](https://docs.jdcloud.com/cn/virtual-machines/reboot-instance); ; ## 接口说明; - 实例状态必须为运行 `running` 状态，同时实例没有正在进行中的任务时才可以重启。; - 如果云主机实例已欠费或已到期，则无法重启。;  ''',
        description='''
            ; 重启云主机实例。; ; 详细操作说明请参考帮助文档：[重启实例](https://docs.jdcloud.com/cn/virtual-machines/reboot-instance); ; ## 接口说明; - 实例状态必须为运行 `running` 状态，同时实例没有正在进行中的任务时才可以重启。; - 如果云主机实例已欠费或已到期，则无法重启。; 。

            示例: jdc vm reboot-instance  --instance-id xxx
        ''',
    )
    def reboot_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.RebootInstanceRequest import RebootInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = RebootInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--network-interface-id'], dict(help="""(string) 弹性网卡ID。 """, dest='networkInterfaceId',  required=True)),
            (['--auto-delete'], dict(help="""(bool) 随云主机实例自动删除，默认为False。; 受管网卡或授信网卡默认为False并且不支持修改。;  """, dest='autoDelete', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机绑定弹性网卡。; ; 详细操作说明请参考帮助文档：[绑定弹性网卡](https://docs.jdcloud.com/cn/virtual-machines/attach-eni); ; ## 接口说明; - 实例状态必须为 `running` 或 `stopped` 状态，同时实例没有正在进行中的任务时才可以操作。; - 实例中的主网卡是不可以解绑和绑定的，绑定弹性网卡只支持绑定辅助网卡。; - 目标弹性网卡上如果绑定了弹性公网IP，那么其所在的可用区需要与云主机的可用区保持一致，或者弹性公网IP是全可用区类型的，才允许绑定该弹性网卡。; - 弹性网卡与云主机必须在相同vpc下。; - 对于受管网卡，授权中不能含有 `instance-attach` 用户才可以挂载。; - 对于授信网卡，授权中必须含有 `instance-attach` 用户才可以挂载。; - 实例挂载弹性网卡的数量，不能超过实例规格的限制。可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得指定规格可挂载弹性网卡的数量上限。;  ''',
        description='''
            ; 为云主机绑定弹性网卡。; ; 详细操作说明请参考帮助文档：[绑定弹性网卡](https://docs.jdcloud.com/cn/virtual-machines/attach-eni); ; ## 接口说明; - 实例状态必须为 `running` 或 `stopped` 状态，同时实例没有正在进行中的任务时才可以操作。; - 实例中的主网卡是不可以解绑和绑定的，绑定弹性网卡只支持绑定辅助网卡。; - 目标弹性网卡上如果绑定了弹性公网IP，那么其所在的可用区需要与云主机的可用区保持一致，或者弹性公网IP是全可用区类型的，才允许绑定该弹性网卡。; - 弹性网卡与云主机必须在相同vpc下。; - 对于受管网卡，授权中不能含有 `instance-attach` 用户才可以挂载。; - 对于授信网卡，授权中必须含有 `instance-attach` 用户才可以挂载。; - 实例挂载弹性网卡的数量，不能超过实例规格的限制。可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得指定规格可挂载弹性网卡的数量上限。; 。

            示例: jdc vm attach-network-interface  --instance-id xxx --network-interface-id xxx
        ''',
    )
    def attach_network_interface(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.AttachNetworkInterfaceRequest import AttachNetworkInterfaceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = AttachNetworkInterfaceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--network-interface-id'], dict(help="""(string) 弹性网卡ID """, dest='networkInterfaceId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机解绑弹性网卡。; ; 详细操作说明请参考帮助文档：[解绑弹性网卡](https://docs.jdcloud.com/cn/virtual-machines/detach-eni); ; ## 接口说明; - 实例状态必须为 `running` 或 `stopped` 状态，同时实例没有正在进行中的任务时才可以操作。; - 实例中的主网卡是不可以解绑和绑定的，解绑弹性网卡只支持解绑辅助网卡。;  ''',
        description='''
            ; 为云主机解绑弹性网卡。; ; 详细操作说明请参考帮助文档：[解绑弹性网卡](https://docs.jdcloud.com/cn/virtual-machines/detach-eni); ; ## 接口说明; - 实例状态必须为 `running` 或 `stopped` 状态，同时实例没有正在进行中的任务时才可以操作。; - 实例中的主网卡是不可以解绑和绑定的，解绑弹性网卡只支持解绑辅助网卡。; 。

            示例: jdc vm detach-network-interface  --instance-id xxx --network-interface-id xxx
        ''',
    )
    def detach_network_interface(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DetachNetworkInterfaceRequest import DetachNetworkInterfaceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DetachNetworkInterfaceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--networks'], dict(help="""(array: instanceNetworkAttribute) 弹性网卡列表。 """, dest='networks',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改云主机弹性网卡属性。; ; 详细操作说明请参考帮助文档：[配置弹性网卡删除属性](https://docs.jdcloud.com/cn/virtual-machines/configurate-eni-delete-attributes); ; ## 接口说明; - 当前只支持修改随云主机实例删除的属性。; - 不支持修改主网卡。;  ''',
        description='''
            ; 修改云主机弹性网卡属性。; ; 详细操作说明请参考帮助文档：[配置弹性网卡删除属性](https://docs.jdcloud.com/cn/virtual-machines/configurate-eni-delete-attributes); ; ## 接口说明; - 当前只支持修改随云主机实例删除的属性。; - 不支持修改主网卡。; 。

            示例: jdc vm modify-instance-network-attribute  --instance-id xxx --networks ['{"":""}']
        ''',
    )
    def modify_instance_network_attribute(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyInstanceNetworkAttributeRequest import ModifyInstanceNetworkAttributeRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyInstanceNetworkAttributeRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--elastic-ip-id'], dict(help="""(string) 弹性公网IP的ID。 """, dest='elasticIpId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机绑定弹性公网IP。; ; 详细操作说明请参考帮助文档：[绑定弹性公网IP](https://docs.jdcloud.com/cn/virtual-machines/associate-elastic-ip); ; ## 接口说明; - 该接口只支持在实例的主网卡的主内网IP上绑定弹性公网IP。; - 一台云主机的主网卡的主内网IP只能绑定一个弹性公网IP，若已绑定弹性公网IP，操作绑定会返回错误。; - 弹性公网IP所在的可用区需要与云主机的可用区保持一致，或者弹性公网IP是全可用区类型的，才允许绑定操作。;  ''',
        description='''
            ; 为云主机绑定弹性公网IP。; ; 详细操作说明请参考帮助文档：[绑定弹性公网IP](https://docs.jdcloud.com/cn/virtual-machines/associate-elastic-ip); ; ## 接口说明; - 该接口只支持在实例的主网卡的主内网IP上绑定弹性公网IP。; - 一台云主机的主网卡的主内网IP只能绑定一个弹性公网IP，若已绑定弹性公网IP，操作绑定会返回错误。; - 弹性公网IP所在的可用区需要与云主机的可用区保持一致，或者弹性公网IP是全可用区类型的，才允许绑定操作。; 。

            示例: jdc vm associate-elastic-ip  --instance-id xxx --elastic-ip-id xxx
        ''',
    )
    def associate_elastic_ip(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.AssociateElasticIpRequest import AssociateElasticIpRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = AssociateElasticIpRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--elastic-ip-id'], dict(help="""(string) 弹性公网IP的ID。 """, dest='elasticIpId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机解绑弹性公网IP。; ; 详细操作说明请参考帮助文档：[解绑弹性公网IP](https://docs.jdcloud.com/cn/virtual-machines/disassociate-elastic-ip); ; ## 接口说明; - 该接口只支持解绑实例的主网卡的主内网IP上的弹性公网IP。;  ''',
        description='''
            ; 为云主机解绑弹性公网IP。; ; 详细操作说明请参考帮助文档：[解绑弹性公网IP](https://docs.jdcloud.com/cn/virtual-machines/disassociate-elastic-ip); ; ## 接口说明; - 该接口只支持解绑实例的主网卡的主内网IP上的弹性公网IP。; 。

            示例: jdc vm disassociate-elastic-ip  --instance-id xxx --elastic-ip-id xxx
        ''',
    )
    def disassociate_elastic_ip(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DisassociateElasticIpRequest import DisassociateElasticIpRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DisassociateElasticIpRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--name'], dict(help="""(string) 镜像名称，长度为2\~32个字符，只允许中文、数字、大小写字母、英文下划线（\_）、连字符（-）及点（.）。;  """, dest='name',  required=True)),
            (['--description'], dict(help="""(string) 镜像描述。256字符以内。;  """, dest='description',  required=False)),
            (['--data-disks'], dict(help="""(array: instanceDiskAttachmentSpec) 数据盘列表。; 在不指定该参数的情况下，制作镜像的过程中会将该实例中的所有云盘数据盘制作快照，并与系统盘一起，制作成打包镜像。; 如果不希望将实例中的某个云盘数据盘制作快照，可使用 `noDevice` 的方式排除，例如：`deviceName=vdb`、`noDevice=true` 就不会将 `vdb` 制作快照。; 如果希望在打包镜像中插入一块新盘，该盘不在实例中，可通过指定新的 `deviceName` 的方式实现，例如：`deviceName=vdx` 将会在打包镜像中插入一块盘符为 `vdx` 的新盘，支持新盘使用或不使用快照都可以。; 如果使用 `deviceName` 指定了与实例中相同的盘符，那么实例中对应的云盘数据盘也不会制作快照，并使用新指定的参数进行替换。;  """, dest='dataDisks',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为云主机制作私有镜像。; ; 详细操作说明请参考帮助文档：[基于实例创建私有镜像](https://docs.jdcloud.com/cn/virtual-machines/create-private-image); ; ## 接口说明; - 云主机实例没有正在进行中的任务时才可制作镜像。; - 本地系统盘的实例，仅支持关机（已停止）状态下制作私有镜像。; - 云盘系统盘的实例，支持开机(运行中)/关机（已停止）状态下制作私有镜像。; - 调用接口后，需要等待镜像状态变为 `ready` 后，才能正常使用镜像。; - 若当前实例系统盘为本地盘，则创建完成后的私有镜像为本地盘系统盘镜像；若当前实例系统盘为云硬盘，则创建完成后的私有镜像为云硬盘系统盘镜像。您可通过镜像类型转换 [convertImage](https://docs.jdcloud.com/Image/api/convertimage) 将本地盘系统盘镜像转换为云硬盘系统盘镜像后使用。; - 默认情况下，制作的镜像中包括数据盘中的云硬盘（制作快照），但是不包含本地数据盘。; - 如果需要变更打包镜像中的一些数据盘、或排除一些数据盘不需要制作快照，可通过 `dataDisks` 中的参数进行控制。;  ''',
        description='''
            ; 为云主机制作私有镜像。; ; 详细操作说明请参考帮助文档：[基于实例创建私有镜像](https://docs.jdcloud.com/cn/virtual-machines/create-private-image); ; ## 接口说明; - 云主机实例没有正在进行中的任务时才可制作镜像。; - 本地系统盘的实例，仅支持关机（已停止）状态下制作私有镜像。; - 云盘系统盘的实例，支持开机(运行中)/关机（已停止）状态下制作私有镜像。; - 调用接口后，需要等待镜像状态变为 `ready` 后，才能正常使用镜像。; - 若当前实例系统盘为本地盘，则创建完成后的私有镜像为本地盘系统盘镜像；若当前实例系统盘为云硬盘，则创建完成后的私有镜像为云硬盘系统盘镜像。您可通过镜像类型转换 [convertImage](https://docs.jdcloud.com/Image/api/convertimage) 将本地盘系统盘镜像转换为云硬盘系统盘镜像后使用。; - 默认情况下，制作的镜像中包括数据盘中的云硬盘（制作快照），但是不包含本地数据盘。; - 如果需要变更打包镜像中的一些数据盘、或排除一些数据盘不需要制作快照，可通过 `dataDisks` 中的参数进行控制。; 。

            示例: jdc vm create-image  --instance-id xxx --name xxx
        ''',
    )
    def create_image(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.CreateImageRequest import CreateImageRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = CreateImageRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--disk-id'], dict(help="""(string) 云硬盘ID。 """, dest='diskId',  required=True)),
            (['--device-name'], dict(help="""(string) 磁盘逻辑挂载点。; **系统盘**：必须指定并且只能是vda。; **数据盘**：取值范围：`[vdb~vdbm]`。;  """, dest='deviceName',  required=False)),
            (['--auto-delete'], dict(help="""(bool) 是否随实例一起删除，即删除实例时是否自动删除此磁盘。此参数仅对按配置计费的非多点挂载云硬盘生效。; 可选值：; `true`：随实例删除。; `false`（默认值）：不随实例删除。;  """, dest='autoDelete', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为一台云主机挂载云硬盘。; ; 详细操作说明请参考帮助文档：[挂载云硬盘](https://docs.jdcloud.com/cn/virtual-machines/attach-cloud-disk); ; ## 接口说明; - 云主机和云硬盘都没有正在进行中的的任务时才可以操作。; - 云主机状态必须是 `running` 或 `stopped` 状态。操作系统盘时必须先停止实例。; - 实例挂载云硬盘的数量，不能超过实例规格的限制。可查询  [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes)  接口获得指定规格可挂载云硬盘的数量上限。; - 云硬盘作为系统盘时，容量不能小于40GB，并且不能超过500GB。; - 待挂载的云硬盘与云主机实例必须在同一个可用区下。; - 共享型云硬盘最多可挂载16个云主机实例，并且只能用作数据盘，不能用于系统盘。非共享型云盘最多只能挂载一个云主机实例。;  ''',
        description='''
            ; 为一台云主机挂载云硬盘。; ; 详细操作说明请参考帮助文档：[挂载云硬盘](https://docs.jdcloud.com/cn/virtual-machines/attach-cloud-disk); ; ## 接口说明; - 云主机和云硬盘都没有正在进行中的的任务时才可以操作。; - 云主机状态必须是 `running` 或 `stopped` 状态。操作系统盘时必须先停止实例。; - 实例挂载云硬盘的数量，不能超过实例规格的限制。可查询  [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes)  接口获得指定规格可挂载云硬盘的数量上限。; - 云硬盘作为系统盘时，容量不能小于40GB，并且不能超过500GB。; - 待挂载的云硬盘与云主机实例必须在同一个可用区下。; - 共享型云硬盘最多可挂载16个云主机实例，并且只能用作数据盘，不能用于系统盘。非共享型云盘最多只能挂载一个云主机实例。; 。

            示例: jdc vm attach-disk  --instance-id xxx --disk-id xxx
        ''',
    )
    def attach_disk(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.AttachDiskRequest import AttachDiskRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = AttachDiskRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--disk-id'], dict(help="""(string) 云硬盘ID。 """, dest='diskId',  required=True)),
            (['--force'], dict(help="""(bool) 是否强制缷载，默认False。; 如果此参数传值为True，数据盘的IO会被强制断掉。;  """, dest='force', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 为一台云主机缷载云硬盘; ; 详细操作说明请参考帮助文档：[缷载云硬盘](https://docs.jdcloud.com/cn/virtual-machines/detach-cloud-disk); ; ## 接口说明; - 云主机和云硬盘都没有正在进行中的的任务时才可以操作。; - 云主机状态必须是 `running` 或 `stopped` 状态。操作系统盘时必须先停止实例。;  ''',
        description='''
            ; 为一台云主机缷载云硬盘; ; 详细操作说明请参考帮助文档：[缷载云硬盘](https://docs.jdcloud.com/cn/virtual-machines/detach-cloud-disk); ; ## 接口说明; - 云主机和云硬盘都没有正在进行中的的任务时才可以操作。; - 云主机状态必须是 `running` 或 `stopped` 状态。操作系统盘时必须先停止实例。; 。

            示例: jdc vm detach-disk  --instance-id xxx --disk-id xxx
        ''',
    )
    def detach_disk(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DetachDiskRequest import DetachDiskRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DetachDiskRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--data-disks'], dict(help="""(array: instanceDiskAttribute) 云硬盘列表。 """, dest='dataDisks',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改一台云主机中的云硬盘属性。; ; 详细操作说明请参考帮助文档：[配置云硬盘删除属性](https://docs.jdcloud.com/cn/virtual-machines/configurate-delete-attributes); ; ## 接口说明; - 该接口当前只能修改实例中的云硬盘随实例删除属性。; - 仅按配置计费、并且非共享型的云硬盘支持修改。; - 包年包月计费的云硬盘该属性不生效，实例删除时云硬盘将保留。;  ''',
        description='''
            ; 修改一台云主机中的云硬盘属性。; ; 详细操作说明请参考帮助文档：[配置云硬盘删除属性](https://docs.jdcloud.com/cn/virtual-machines/configurate-delete-attributes); ; ## 接口说明; - 该接口当前只能修改实例中的云硬盘随实例删除属性。; - 仅按配置计费、并且非共享型的云硬盘支持修改。; - 包年包月计费的云硬盘该属性不生效，实例删除时云硬盘将保留。; 。

            示例: jdc vm modify-instance-disk-attribute  --instance-id xxx
        ''',
    )
    def modify_instance_disk_attribute(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyInstanceDiskAttributeRequest import ModifyInstanceDiskAttributeRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyInstanceDiskAttributeRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--name'], dict(help="""(string) 实例名称。长度为2\~128个字符，只允许中文、数字、大小写字母、英文下划线（\_）、连字符（-）及点（.），不能以（.）作为首尾。;  """, dest='name',  required=False)),
            (['--description'], dict(help="""(string) 实例描述。256字符以内。;  """, dest='description',  required=False)),
            (['--hostname'], dict(help="""(string) 实例hostname。; **Windows系统**：长度为2\~15个字符，允许大小写字母、数字或连字符（-），不能以连字符（-）开头或结尾，不能连续使用连字符（-），也不能全部使用数字。不支持点号（.）。; **Linux系统**：长度为2-64个字符，允许支持多个点号，点之间为一段，每段允许使用大小写字母、数字或连字符（-），但不能连续使用点号（.）或连字符（-），不能以点号（.）或连字符（-）开头或结尾。;  """, dest='hostname',  required=False)),
            (['--metadata'], dict(help="""(array: metadata) 用户自定义元数据。; 以 `key-value` 键值对形式指定，可在实例系统内通过元数据服务查询获取。最多支持40对键值对，且 `key` 不超过256字符，`value` 不超过16KB，不区分大小写。; 注意：`key` 不要以连字符(-)结尾，否则此 `key` 不生效。;  """, dest='metadata',  required=False)),
            (['--userdata'], dict(help="""(array: userdata) 自定义脚本。; 目前仅支持启动脚本，即 `launch-script`，须Base64编码且编码前数据长度不能超过16KB。; **linux系统**：支持bash和python，编码前须分别以 `#!/bin/bash` 和 `#!/usr/bin/env python` 作为内容首行。; **Windows系统**：支持 `bat` 和 `powershell` ，编码前须分别以 `<cmd></cmd>和<powershell></powershell>` 作为内容首、尾行。;  """, dest='userdata',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改一台云主机的属性。; ; 详细操作说明请参考帮助文档：; [修改实例名称](https://docs.jdcloud.com/cn/virtual-machines/modify-instance-name); [自定义数据](https://docs.jdcloud.com/cn/virtual-machines/userdata); [实例元数据](https://docs.jdcloud.com/cn/virtual-machines/instance-metadata); ; ## 接口说明; - 支持修改实例的名称、描述、hostname、自定义数据、实例元数据。;  ''',
        description='''
            ; 修改一台云主机的属性。; ; 详细操作说明请参考帮助文档：; [修改实例名称](https://docs.jdcloud.com/cn/virtual-machines/modify-instance-name); [自定义数据](https://docs.jdcloud.com/cn/virtual-machines/userdata); [实例元数据](https://docs.jdcloud.com/cn/virtual-machines/instance-metadata); ; ## 接口说明; - 支持修改实例的名称、描述、hostname、自定义数据、实例元数据。; 。

            示例: jdc vm modify-instance-attribute  --instance-id xxx
        ''',
    )
    def modify_instance_attribute(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyInstanceAttributeRequest import ModifyInstanceAttributeRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyInstanceAttributeRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--subnet-id'], dict(help="""(string) 子网Id。 """, dest='subnetId',  required=True)),
            (['--assign-ipv6'], dict(help="""(bool) `true`: 分配IPV6地址。; `false`: 不分配IPV6地址。;  """, dest='assignIpv6', type=bool, required=False)),
            (['--private-ip-address'], dict(help="""(string) Ipv4地址。; 不变更 `vpc` 及子网时必须指定Ipv4地址;  """, dest='privateIpAddress',  required=False)),
            (['--security-groups'], dict(help="""(array: string) 安全组列表。; 更换 `vpc` 时必须指定新的安全组。; 不更换 `vpc` 时不可以指定安全组。;  """, dest='securityGroups',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改一台云主机的子网或内网IP地址。; ; 详细操作说明请参考帮助文档：[修改网络配置](https://docs.jdcloud.com/cn/virtual-machines/modify-vpc-attribute); ; ## 接口说明; - 调该接口之前实例必须处于停止 `stopped` 状态。; - 修改VPC及子网;   - 内网IPv4：可指定或由系统分配。;   - IPv6：如新子网支持IPv6，可选是否分配，如分配仅支持系统分配。;   - 安全组：须指定新VPC下的安全组。; - 不修改VPC，仅修改子网;   - 内网IPv4：可指定或由系统分配。;   - IPv6：如新子网支持IPv6，可选是否分配，如分配仅支持系统分配。;   - 安全组：不支持绑定新安全组。; - 不修改VPC及子网，仅更换内网IP;   - 内网IPv4：须指定IP地址。;   - IPv6：不支持修改。;   - 安全组：不支持绑定新安全组。; - 一些限制及注意事项：;   - 已加入负载均衡-后端服务器组中的实例不允许修改。;   - 绑定弹性网卡的实例不支持修改VPC，仅支持在同VPC下修改子网和内网IP。;   - 主网卡分配了辅助内网IP的实例不支持修改VPC和子网，仅支持在同子网下修改内网IP。;   - 如实例在高可用组内，则不允许修改VPC，仅可在同VPC内修改子网或内网IPv4地址。;   - 仅在更换VPC时传入安全组ID才有效，且安全组须隶属于目标VPC。;   - 如指定内网IPv4，须确保IP地址在子网网段内且未被占用；如不指定则随机分配，须确保子网可用IP充足。;  ''',
        description='''
            ; 修改一台云主机的子网或内网IP地址。; ; 详细操作说明请参考帮助文档：[修改网络配置](https://docs.jdcloud.com/cn/virtual-machines/modify-vpc-attribute); ; ## 接口说明; - 调该接口之前实例必须处于停止 `stopped` 状态。; - 修改VPC及子网;   - 内网IPv4：可指定或由系统分配。;   - IPv6：如新子网支持IPv6，可选是否分配，如分配仅支持系统分配。;   - 安全组：须指定新VPC下的安全组。; - 不修改VPC，仅修改子网;   - 内网IPv4：可指定或由系统分配。;   - IPv6：如新子网支持IPv6，可选是否分配，如分配仅支持系统分配。;   - 安全组：不支持绑定新安全组。; - 不修改VPC及子网，仅更换内网IP;   - 内网IPv4：须指定IP地址。;   - IPv6：不支持修改。;   - 安全组：不支持绑定新安全组。; - 一些限制及注意事项：;   - 已加入负载均衡-后端服务器组中的实例不允许修改。;   - 绑定弹性网卡的实例不支持修改VPC，仅支持在同VPC下修改子网和内网IP。;   - 主网卡分配了辅助内网IP的实例不支持修改VPC和子网，仅支持在同子网下修改内网IP。;   - 如实例在高可用组内，则不允许修改VPC，仅可在同VPC内修改子网或内网IPv4地址。;   - 仅在更换VPC时传入安全组ID才有效，且安全组须隶属于目标VPC。;   - 如指定内网IPv4，须确保IP地址在子网网段内且未被占用；如不指定则随机分配，须确保子网可用IP充足。; 。

            示例: jdc vm modify-instance-vpc-attribute  --instance-id xxx --subnet-id xxx
        ''',
    )
    def modify_instance_vpc_attribute(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyInstanceVpcAttributeRequest import ModifyInstanceVpcAttributeRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyInstanceVpcAttributeRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--password'], dict(help="""(string) 实例密码。; 可用于SSH登录和VNC登录。; 长度为8\~30个字符，必须同时包含大、小写英文字母、数字和特殊符号中的三类字符。特殊符号包括：`\(\)\`~!@#$%^&\*\_-+=\|{}\[ ]:";'<>,.?/，`。; 更多密码输入要求请参见 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。;  """, dest='password',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 修改云主机密码。; ; 详细操作说明请参考帮助文档：[重置密码](https://docs.jdcloud.com/cn/virtual-machines/reset-password); ; ## 接口说明; - 实例没有正在进行中的任务时才可操作。; - 重置密码后，需要重启云主机后生效。;  ''',
        description='''
            ; 修改云主机密码。; ; 详细操作说明请参考帮助文档：[重置密码](https://docs.jdcloud.com/cn/virtual-machines/reset-password); ; ## 接口说明; - 实例没有正在进行中的任务时才可操作。; - 重置密码后，需要重启云主机后生效。; 。

            示例: jdc vm modify-instance-password  --instance-id xxx --password xxx
        ''',
    )
    def modify_instance_password(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyInstancePasswordRequest import ModifyInstancePasswordRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyInstancePasswordRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 获取云主机vnc地址。; ; 详细操作说明请参考帮助文档：[连接实例](https://docs.jdcloud.com/cn/virtual-machines/connect-to-instance); ; ## 接口说明; - 实例仅 `running` 状态时才可获取到 `vnc` 地址。; - 调用该接口可获取云主机 `vnc` 地址，用于远程连接管理云主机。; - `vnc` 地址的有效期为1个小时，调用接口获取vnc地址后如果1个小时内没有使用，`vnc` 地址将自动失效，再次使用需要重新获取。; - 裸金属实例目前不支持通过 `vnc` 登录。;  ''',
        description='''
            ; 获取云主机vnc地址。; ; 详细操作说明请参考帮助文档：[连接实例](https://docs.jdcloud.com/cn/virtual-machines/connect-to-instance); ; ## 接口说明; - 实例仅 `running` 状态时才可获取到 `vnc` 地址。; - 调用该接口可获取云主机 `vnc` 地址，用于远程连接管理云主机。; - `vnc` 地址的有效期为1个小时，调用接口获取vnc地址后如果1个小时内没有使用，`vnc` 地址将自动失效，再次使用需要重新获取。; - 裸金属实例目前不支持通过 `vnc` 登录。; 。

            示例: jdc vm describe-instance-vnc-url  --instance-id xxx
        ''',
    )
    def describe_instance_vnc_url(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceVncUrlRequest import DescribeInstanceVncUrlRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceVncUrlRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--instance-type'], dict(help="""(string) 实例规格，可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得指定地域或可用区的规格信息。 """, dest='instanceType',  required=True)),
            (['--force'], dict(help="""(bool) 是否强制调配，默认为 `false`。如果指定为 `true`, 将会清除本地数据盘。 """, dest='force', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 变更云主机实例配置。; ; 详细操作说明请参考帮助文档：[调整配置](https://docs.jdcloud.com/cn/virtual-machines/resize-instance); ; ## 接口说明;   - 云主机的状态必须为 `stopped` 状态。;   - 16年创建的云硬盘做系统盘的云主机，实例规格不允许跨代调配。;   - 若当前实例系统盘为本地盘，则不允许跨代调配，例如第一代云主机不允许与第二代云主机互相调配，且不允许调整至第一代存储优化大数据型 `s.d1` 及第二代存储优化大数据型 `s.d2`。;   - 若当前实例在高可用组内，则不允许调配至除GPU类型外的第一代云主机，受限于高可用组支持的规格情况。;   - 若当前实例已挂载加密云盘，则不允许调配至第一代云主机，受限于支持加密盘的规格情况。;   - 裸金属实例规格主机暂不支持调配，即不支持从其他规格调整为裸金属规格或从裸金属规格调整为其他规格。;   - 对于按配置计费实例，调整配置后将按照新规格计费，调整前规格会立即出账结算（即对上次整点结算时间至当前时间产生的费用进行结算）。;   - 若当前实例带有本地数据盘，需清除本地盘内数据才可调整配置，还请谨慎操作。;   - 对于包年包月计费云主机：; 	- 若调配后规格价格低于调配前规格价格，则将延长云主机到期时间；; 	- 若调配后规格价格高于调配前规格价格，需要支付到期前的差价。;   - 如果当前主机中的弹性网卡数量，超过了目标实例规格允许的弹性网卡数量，会返回错误。可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得实例规格允许的弹性网卡数量。;   - 如果当前主机中的云硬盘数据，超过了目标实例规格允许的云硬盘数量，会返回错误。可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得实例规格允许的云硬盘数量。;   - 当前主机所使用的镜像，需要支持目标实例规格，否则返回错误。可查询 [DescribeImageConstraints](docs.jdcloud.com/virtual-machines/api/describeimageconstraints) 接口获得指定镜像的实例规格限制信息。;   - 云主机欠费或到期时，无法更改实例规格。;  ''',
        description='''
            ; 变更云主机实例配置。; ; 详细操作说明请参考帮助文档：[调整配置](https://docs.jdcloud.com/cn/virtual-machines/resize-instance); ; ## 接口说明;   - 云主机的状态必须为 `stopped` 状态。;   - 16年创建的云硬盘做系统盘的云主机，实例规格不允许跨代调配。;   - 若当前实例系统盘为本地盘，则不允许跨代调配，例如第一代云主机不允许与第二代云主机互相调配，且不允许调整至第一代存储优化大数据型 `s.d1` 及第二代存储优化大数据型 `s.d2`。;   - 若当前实例在高可用组内，则不允许调配至除GPU类型外的第一代云主机，受限于高可用组支持的规格情况。;   - 若当前实例已挂载加密云盘，则不允许调配至第一代云主机，受限于支持加密盘的规格情况。;   - 裸金属实例规格主机暂不支持调配，即不支持从其他规格调整为裸金属规格或从裸金属规格调整为其他规格。;   - 对于按配置计费实例，调整配置后将按照新规格计费，调整前规格会立即出账结算（即对上次整点结算时间至当前时间产生的费用进行结算）。;   - 若当前实例带有本地数据盘，需清除本地盘内数据才可调整配置，还请谨慎操作。;   - 对于包年包月计费云主机：; 	- 若调配后规格价格低于调配前规格价格，则将延长云主机到期时间；; 	- 若调配后规格价格高于调配前规格价格，需要支付到期前的差价。;   - 如果当前主机中的弹性网卡数量，超过了目标实例规格允许的弹性网卡数量，会返回错误。可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得实例规格允许的弹性网卡数量。;   - 如果当前主机中的云硬盘数据，超过了目标实例规格允许的云硬盘数量，会返回错误。可查询 [DescribeInstanceTypes](https://docs.jdcloud.com/virtual-machines/api/describeinstancetypes) 接口获得实例规格允许的云硬盘数量。;   - 当前主机所使用的镜像，需要支持目标实例规格，否则返回错误。可查询 [DescribeImageConstraints](docs.jdcloud.com/virtual-machines/api/describeimageconstraints) 接口获得指定镜像的实例规格限制信息。;   - 云主机欠费或到期时，无法更改实例规格。; 。

            示例: jdc vm resize-instance  --instance-id xxx --instance-type xxx
        ''',
    )
    def resize_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ResizeInstanceRequest import ResizeInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ResizeInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--password'], dict(help="""(string) 实例密码。; 可用于SSH登录和VNC登录。; 长度为8\~30个字符，必须同时包含大、小写英文字母、数字和特殊符号中的三类字符。特殊符号包括：`\(\)\`~!@#$%^&\*\_-+=\|{}\[ ]:";'<>,.?/，`。; 更多密码输入要求请参见 [公共参数规范](https://docs.jdcloud.com/virtual-machines/api/general_parameters)。;  """, dest='password',  required=False)),
            (['--image-id'], dict(help="""(string) 镜像ID。; 若不指定镜像ID，默认使用当前主机的原镜像重置系统。; 可查询 [DescribeImages](https://docs.jdcloud.com/virtual-machines/api/describeimages) 接口获得指定地域的镜像信息。;  """, dest='imageId',  required=False)),
            (['--key-names'], dict(help="""(array: string) 密钥对名称。仅Linux系统下该参数生效，当前仅支持输入单个密钥。;  """, dest='keyNames',  required=False)),
            (['--hostname'], dict(help="""(string) 实例hostname。; 若不指定hostname，则默认以实例名称`name`作为hostname，但是会以RFC 952和RFC 1123命名规范做一定转义。; **Windows系统**：长度为2\~15个字符，允许大小写字母、数字或连字符（-），不能以连字符（-）开头或结尾，不能连续使用连字符（-），也不能全部使用数字。不支持点号（.）。; **Linux系统**：长度为2-64个字符，允许支持多个点号，点之间为一段，每段允许使用大小写字母、数字或连字符（-），但不能连续使用点号（.）或连字符（-），不能以点号（.）或连字符（-）开头或结尾。;  """, dest='hostname',  required=False)),
            (['--metadata'], dict(help="""(array: metadata) 用户自定义元数据。; 以 `key-value` 键值对形式指定，可在实例系统内通过元数据服务查询获取。最多支持40对键值对，且 `key` 不超过256字符，`value` 不超过16KB，不区分大小写。; 注意：`key` 不要以连字符(-)结尾，否则此 `key` 不生效。;  """, dest='metadata',  required=False)),
            (['--userdata'], dict(help="""(array: userdata) 自定义脚本。; 目前仅支持启动脚本，即 `launch-script`，须Base64编码且编码前数据长度不能超过16KB。; **linux系统**：支持bash和python，编码前须分别以 `#!/bin/bash` 和 `#!/usr/bin/env python` 作为内容首行。; **Windows系统**：支持 `bat` 和 `powershell`，编码前须分别以 `<cmd></cmd>和<powershell></powershell>` 作为内容首、尾行。;  """, dest='userdata',  required=False)),
            (['--pass-word-auth'], dict(help="""(string) 密码授权，若存在密匙，则根据此参数决定是否使用密码，若没有密匙，此参数无效，会强制使用密码。; 若不使用密码，且密匙对解绑后，用户需重置密码，方可使用密码登录。; 此参数在windows系统中必须为yes。;  """, dest='passWordAuth',  required=False)),
            (['--image-inherit'], dict(help="""(string) 继承镜像中的登录验证方式，"yes"为使用，"no"为不使用，""默认为"no" """, dest='imageInherit',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 重置云主机系统。; ; 需要注意的是，重装系统会导致系统盘的内容全部丢失，数据盘的数据不受影响（但需要重新识别）。因此，在需要保留系统运行数据的情况下，强烈建议您在重置系统前制作私有镜像，之后重置时选择该私有镜像即可实现保留系统运行数据。; ; 详细操作说明请参考帮助文档：[重置系统](https://docs.jdcloud.com/cn/virtual-machines/rebuild-instance); ; ## 接口说明; - 云主机的状态必须为 `stopped` 状态。; - 若实例基于私有镜像创建，而私有镜像已被删除，则无法使用原镜像重置系统，即无法恢复至刚创建时的系统状态，建议保留被实例引用的私有镜像。; - 重置系统需要重新指定密码，对于 `Linux` 系统您还可以重新指定 `SSH密钥`。; - 对于云盘作系统盘的实例，当前系统盘大小不能超过目标镜像对应系统盘快照的容量。; - 云主机系统盘类型必须与待更换镜像支持的系统盘类型保持一致，若当前云主机系统盘为 `local` 类型，则更换镜像的系统盘类型必须为 `loaclDisk` 类型；同理，若当前云主机系统盘为 `cloud` 类型，则更换镜像的系统盘类型必须为 `cloudDisk` 类型。可查询 [DescribeImages](https://docs.jdcloud.com/virtual-machines/api/describeimages) 接口获得指定地域的镜像信息。; - 指定的镜像必须能够支持当前主机的实例规格 `instanceType`，否则会返回错误。可查询 [DescribeImageConstraints](docs.jdcloud.com/virtual-machines/api/describeimageconstraints) 接口获得指定镜像支持的系统盘类型信息。;  ''',
        description='''
            ; 重置云主机系统。; ; 需要注意的是，重装系统会导致系统盘的内容全部丢失，数据盘的数据不受影响（但需要重新识别）。因此，在需要保留系统运行数据的情况下，强烈建议您在重置系统前制作私有镜像，之后重置时选择该私有镜像即可实现保留系统运行数据。; ; 详细操作说明请参考帮助文档：[重置系统](https://docs.jdcloud.com/cn/virtual-machines/rebuild-instance); ; ## 接口说明; - 云主机的状态必须为 `stopped` 状态。; - 若实例基于私有镜像创建，而私有镜像已被删除，则无法使用原镜像重置系统，即无法恢复至刚创建时的系统状态，建议保留被实例引用的私有镜像。; - 重置系统需要重新指定密码，对于 `Linux` 系统您还可以重新指定 `SSH密钥`。; - 对于云盘作系统盘的实例，当前系统盘大小不能超过目标镜像对应系统盘快照的容量。; - 云主机系统盘类型必须与待更换镜像支持的系统盘类型保持一致，若当前云主机系统盘为 `local` 类型，则更换镜像的系统盘类型必须为 `loaclDisk` 类型；同理，若当前云主机系统盘为 `cloud` 类型，则更换镜像的系统盘类型必须为 `cloudDisk` 类型。可查询 [DescribeImages](https://docs.jdcloud.com/virtual-machines/api/describeimages) 接口获得指定地域的镜像信息。; - 指定的镜像必须能够支持当前主机的实例规格 `instanceType`，否则会返回错误。可查询 [DescribeImageConstraints](docs.jdcloud.com/virtual-machines/api/describeimageconstraints) 接口获得指定镜像支持的系统盘类型信息。; 。

            示例: jdc vm rebuild-instance  --instance-id xxx
        ''',
    )
    def rebuild_instance(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.RebuildInstanceRequest import RebuildInstanceRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = RebuildInstanceRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--page-number'], dict(help="""(int) 页码；默认为1。 """, dest='pageNumber', type=int, required=False)),
            (['--page-size'], dict(help="""(int) 分页大小；默认为10；取值范围[1, 10]。 """, dest='pageSize', type=int, required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceId`: 云主机ID，精确匹配，支持多个; `privateIpAddress`: 主网卡内网主IP地址，模糊匹配，支持多个; `vpcId`: 私有网络ID，精确匹配，支持多个; `status`: 云主机状态，精确匹配，支持多个，参考 [云主机状态](https://docs.jdcloud.com/virtual-machines/api/vm_status); `name`: 云主机名称，模糊匹配，支持单个; `imageId`: 镜像ID，精确匹配，支持多个; `agId`: 使用可用组id，支持单个; `faultDomain`: 错误域，支持多个; `networkInterfaceId`: 弹性网卡ID，精确匹配，支持多个; `subnetId`: 子网ID，精确匹配，支持多个;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 批量查询云主机用户自定义元数据。; ; 详细操作说明请参考帮助文档：[自定义元数据](https://docs.jdcloud.com/cn/virtual-machines/userdata); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询10台云主机实例自定义元数据。;  ''',
        description='''
            ; 批量查询云主机用户自定义元数据。; ; 详细操作说明请参考帮助文档：[自定义元数据](https://docs.jdcloud.com/cn/virtual-machines/userdata); ; ## 接口说明; - 使用 `filters` 过滤器进行条件筛选，每个 `filter` 之间的关系为逻辑与（AND）的关系。; - 单次查询最大可查询10台云主机实例自定义元数据。; 。

            示例: jdc vm describe-instances-custom-data 
        ''',
    )
    def describe_instances_custom_data(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstancesCustomDataRequest import DescribeInstancesCustomDataRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstancesCustomDataRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--instance-id'], dict(help="""(string) 云主机ID。 """, dest='instanceId',  required=True)),
            (['--ag-id'], dict(help="""(string) 高可用组Id，必填项。; 可查询 [DescribeAgs](https://docs.jdcloud.com/cn/availability-group/api/describeags) 接口获得高可用组信息。;  """, dest='agId',  required=False)),
            (['--balance'], dict(help="""(bool) 是否强制均衡，默认 false;  """, dest='balance', type=bool, required=False)),
            (['--clear-local-disk'], dict(help="""(bool) 是否确认清除本地盘数据，默认 false;  """, dest='clearLocalDisk', type=bool, required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 存量主机加入高可用组。; ; 存量主机加入高可用组，或者主机从一个高可用组移动到另一个高可用组; ; ## 接口说明; - 不支持专属宿主机上的实例调整高可用组。; - 除GPU、vGPU（以P开头）外的一代机暂不支持调整高可用组。; - 与该高可用组关联实例模板的VPC不同的不支持调整高可用组。; - 与该高可用组可用区不匹配的实例不支持调整高可用组。; - 本地系统盘机型不支持强制均衡。; - 仅支持实例状态为已停止的实例强制均衡调整高可用组。; - 若不强制均衡，仅支持实例状态为运行中或已停止的实例调整高可用组。; - 若强制均衡，带本地数据盘的实例需确认清除本地盘数据。;  ''',
        description='''
            ; 存量主机加入高可用组。; ; 存量主机加入高可用组，或者主机从一个高可用组移动到另一个高可用组; ; ## 接口说明; - 不支持专属宿主机上的实例调整高可用组。; - 除GPU、vGPU（以P开头）外的一代机暂不支持调整高可用组。; - 与该高可用组关联实例模板的VPC不同的不支持调整高可用组。; - 与该高可用组可用区不匹配的实例不支持调整高可用组。; - 本地系统盘机型不支持强制均衡。; - 仅支持实例状态为已停止的实例强制均衡调整高可用组。; - 若不强制均衡，仅支持实例状态为运行中或已停止的实例调整高可用组。; - 若强制均衡，带本地数据盘的实例需确认清除本地盘数据。; 。

            示例: jdc vm modify-instance-placement  --instance-id xxx
        ''',
    )
    def modify_instance_placement(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.ModifyInstancePlacementRequest import ModifyInstancePlacementRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = ModifyInstancePlacementRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--region-id'], dict(help="""(string) 地域ID。 """, dest='regionId',  required=False)),
            (['--service-name'], dict(help="""(string) 产品线类型，默认为 `vm`。支持范围：`vm` 云主机，`nc` 原生容器。 """, dest='serviceName',  required=False)),
            (['--filters'], dict(help="""(array: filter) <b>filters 中支持使用以下关键字进行过滤</b>; `instanceTypes`: 实例规格，精确匹配，支持多个; `az`: 可用区，精确匹配，支持多个; `architecture`: CPU架构，精确匹配，支持单个，可选范围:x86_64或arm64;  """, dest='filters',  required=False)),
            (['--input-json'], dict(help='(json) 以json字符串或文件绝对路径形式作为输入参数。\n字符串方式举例：--input-json \'{"field":"value"}\';\n文件格式举例：--input-json file:///xxxx.json', dest='input_json', required=False)),
            (['--jdcloud-header'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='jdcloudHeaders', required=False)),
            (['--headers'], dict(help="""(json) 用户自定义Header，举例：'{"x-jdcloud-security-token":"abc","test":"123"}'""", dest='headers', required=False)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' ; 查询实例规格列表。; ; 详细操作说明请参考帮助文档：[实例规格类型](https://docs.jdcloud.com/cn/virtual-machines/instance-type-family); ; ## 接口说明; - 调用该接口可查询全量实例规格信息。; - 可查询实例规格的CPU、内存大小、可绑定的弹性网卡数量、可挂载的云硬盘数量，是否售卖等信息。; - GPU 或 本地存储型的规格可查询 GPU型号、GPU卡数量、本地盘数量。; - 尽量使用过滤器查询关心的实例规格，并适当缓存这些信息。否则全量查询可能响应较慢。;  ''',
        description='''
            ; 查询实例规格列表。; ; 详细操作说明请参考帮助文档：[实例规格类型](https://docs.jdcloud.com/cn/virtual-machines/instance-type-family); ; ## 接口说明; - 调用该接口可查询全量实例规格信息。; - 可查询实例规格的CPU、内存大小、可绑定的弹性网卡数量、可挂载的云硬盘数量，是否售卖等信息。; - GPU 或 本地存储型的规格可查询 GPU型号、GPU卡数量、本地盘数量。; - 尽量使用过滤器查询关心的实例规格，并适当缓存这些信息。否则全量查询可能响应较慢。; 。

            示例: jdc vm describe-instance-types 
        ''',
    )
    def describe_instance_types(self):
        client_factory = ClientFactory('vm')
        client = client_factory.get(self.app)
        if client is None:
            return

        try:
            from jdcloud_sdk.services.vm.apis.DescribeInstanceTypesRequest import DescribeInstanceTypesRequest
            params_dict = collect_user_args(self.app)
            headers = collect_user_headers(self.app)
            req = DescribeInstanceTypesRequest(params_dict, headers)
            resp = client.send(req)
            Printer.print_result(resp)
        except ImportError:
            print('{"error":"This api is not supported, please use the newer version"}')
        except Exception as e:
            print(e)

    @expose(
        arguments=[
            (['--api'], dict(help="""(string) api name """, choices=['describe-instance-templates','create-instance-template','describe-instance-template','update-instance-template','delete-instance-template','verify-instance-template','describe-instance-templates-customdata','describe-keypairs','create-keypair','import-keypair','delete-keypair','attach-keypair','detach-keypair','describe-image','delete-image','describe-images','describe-image-constraints','describe-image-constraints-batch','share-image','un-share-image','release-image','un-release-image','describe-image-members','copy-images','modify-image-attribute','import-image','export-image','image-tasks','describe-quotas','describe-instances','create-instances','describe-brief-instances','describe-instance','delete-instance','describe-instance-status','describe-instance-private-ip-address','stop-instance','start-instance','reboot-instance','attach-network-interface','detach-network-interface','modify-instance-network-attribute','associate-elastic-ip','disassociate-elastic-ip','create-image','attach-disk','detach-disk','modify-instance-disk-attribute','modify-instance-attribute','modify-instance-vpc-attribute','modify-instance-password','describe-instance-vnc-url','resize-instance','rebuild-instance','describe-instances-custom-data','modify-instance-placement','describe-instance-types',], required=True)),
        ],
        formatter_class=RawTextHelpFormatter,
        help=''' 生成单个API接口的json骨架空字符串 ''',
        description='''
            生成单个API接口的json骨架空字符串。

            示例: jdc nc generate-skeleton --api describeContainer ''',
    )
    def generate_skeleton(self):
        skeleton = Skeleton('vm', self.app.pargs.api)
        skeleton.show()
